@@ -1,13 +1,14 @@
 /*
- * GNU.FREE 2001
+ * GNU.FREE 2002
  *
- * Copyright (c) 1999, 2000, 2001 The Free Software Foundation (www.fsf.org)
+ * Copyright (c) 1999, 2000, 2001, 2002
+ * The Free Software Foundation (www.fsf.org)
  *
- * GNU.FREE Co-ordinator: Jason Kitcat <jeep@thecouch.org>
+ * GNU.FREE Co-ordinator: Jason Kitcat <jeep@free-project.org>
  *
- * GNU site: http://www.gnu.org/software/gnu.free/gnufree.html
+ * GNU site: http://www.gnu.org/software/free/
  * 
- * FREE e-democracy site: http://www.thecouch.org/free/
+ * FREE e-democracy site: http://www.free-project.org
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +21,7 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program (gpl.txt); if not, write to the Free Software
+ * along with this program (COPYING); if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
@@ -30,6 +31,7 @@ package ERServer;
 import java.io.*;
 import java.sql.*;
 import java.util.*;
+//#ifdef INSTALL
 import org.hsql.*;
 
 import cryptix.provider.key.RawSecretKey;
@@ -57,12 +59,14 @@ import Free.DBPool.*;
  * authorisation system. To implement a new (e.g. biometric) auth system
  * then you *WILL* need to change some SQL. It won't hurt.
  *
- * @version 1.3  20 February 2001
+ * @version 1.8  28 August 2001
  * @author Jason Kitcat
  */
 public class DBase {
 
+//#ifdef INSTALL
 	private static final String username = "sa";
+//#ifdef INSTALL
 	private static final String password = "";
 	// USER SUPPLIED SESSION WORD
 	protected static String cryptword = "";
@@ -76,9 +80,11 @@ public class DBase {
 	
 		try {
 
+//#ifdef INSTALL
 			Class.forName("org.hsql.jdbcDriver"); // Load the Hypersonic SQL JDBC driver
 
 			/* Prepare the pool with currently 10 connections */
+//#ifdef INSTALL
 			new JDCConnectionDriver("org.hsql.jdbcDriver","jdbc:HypersonicSQL:erserver",username, password);
 
 			/* Get a connection from the pool */
@@ -92,7 +98,7 @@ public class DBase {
 				if(ERServer.DEV.isDebugEnabled()) {
 					ERServer.DEV.debug("Roll table didn't exist so creating it");
 				}
-				freeStat.execute("CREATE TABLE Roll(name VARCHAR(255), code VARCHAR(255), pword VARCHAR(255), voted CHAR(1))");
+				freeStat.execute("CREATE TABLE Roll(name VARCHAR(255), code VARCHAR(255), pword VARCHAR(255), voted CHAR(1), vote_where CHAR(1), info_sent CHAR(1), other VARCHAR(255))");
 			}
 
 			DatabaseMetaData dbMetaData = freeConn.getMetaData();
@@ -303,7 +309,7 @@ public class DBase {
 
 
 	/**
-	 * checks Electoral Roll information against that in the database.
+	 * checks Electoral Roll information against that in the database for FreeClient.
 	 *
 	 * @param name  String representing the voter's name
 	 * @param code  String representing the voter's vote-specific code
@@ -324,7 +330,7 @@ public class DBase {
 			Statement freeStat = freeConn.createStatement();
 			
 			/* search for the data */
-			res = freeStat.execute("SELECT voted FROM Roll WHERE name = '" + encrypt(name) + "' AND code = '" + encrypt(code) + "' AND pword = '" + encrypt(pword) + "'");
+			res = freeStat.execute("SELECT voted, vote_where FROM Roll WHERE name = '" + encrypt(name) + "' AND code = '" + encrypt(code) + "' AND pword = '" + encrypt(pword) + "'");
 			result = freeStat.getResultSet();
 		
 			/* check answer */
@@ -332,14 +338,19 @@ public class DBase {
 			if (!res) {
 				temp = false;
 			} else {
-				if (decrypt(result.getString(1)).equals("F")) {  // they haven't already voted
-					temp = true;
-					freeStat.execute("UPDATE Roll SET voted = '" + encrypt("C") + "' WHERE name = '" + encrypt(name) + "' AND code = '" + encrypt(code) + "' AND pword = '" + encrypt(pword) + "'");
-				} else if (decrypt(result.getString(1)).equals("C")) {  // their vote hasn't been registered but they have logged in before
-					temp = true;
-					// no need to change database but write to log just in case
-					ERServer.NORM.info("DBase.checkER(): User already tried to vote but not confirmed");
-				} else {  // otherwise they've already voted
+				if (decrypt(result.getString(2)).equals("I")) { // user authorised to vote online
+					if (decrypt(result.getString(1)).equals("F")) {  // they haven't already voted
+						temp = true;
+						freeStat.execute("UPDATE Roll SET voted = '" + encrypt("C") + "' WHERE name = '" + encrypt(name) + "' AND code = '" + encrypt(code) + "' AND pword = '" + encrypt(pword) + "'");
+					} else if (decrypt(result.getString(1)).equals("C")) {  // their vote hasn't been registered but they have logged in before
+						temp = true;
+						// no need to change database but write to log just in case
+						ERServer.NORM.info("DBase.checkER(): User already tried to vote but not confirmed");
+					} else {  // otherwise they've already voted
+						temp = false;
+					}
+				} else {
+					ERServer.NORM.info("DBase.checkER(): User not authorised to vote online.");
 					temp = false;
 				}
 			}
@@ -349,7 +360,7 @@ public class DBase {
 		} else {
 		
 			temp = false;
-			throw new Exception("checkER - invalid character(s) used");
+			throw new Exception("DBase.checkER() - invalid character(s) used");
 			
 		}
 		
@@ -359,21 +370,77 @@ public class DBase {
 
 	
 	/**
-	 * A little processor intensive and might need tuning but this method finds the user
-	 * entry in the Electoral Roll that matches the received key and sets it has having
-	 * voted.
+	 * checks Electoral Roll information against that in the database for PollManager.
 	 *
 	 * @param name  String representing the voter's name
 	 * @param code  String representing the voter's vote-specific code
 	 * @param pword String representing the voter's password
+	 * @returns    An array of Strings which return: voted status and vote_where
+	 */
+	protected static String[] PMcheckER(String name, String code, String pword) throws Exception {
+	
+		ResultSet result;
+		boolean temp, res;
+		String[] results = new String[] {"", ""};
+	
+		/* boundary check the data first */
+		// only if the data is alphanumeric, punctuation or spaces do we carry on
+		if (isSafe(name)&&isSafe(code)&&isSafe(pword)) {
+
+			/* Get a connection from the pool */
+			Connection freeConn = getConnection();
+			Statement freeStat = freeConn.createStatement();
+			
+			/* search for the data */
+			res = freeStat.execute("SELECT voted, vote_where FROM Roll WHERE name = '" + encrypt(name) + "' AND code = '" + encrypt(code) + "' AND pword = '" + encrypt(pword) + "'");
+			result = freeStat.getResultSet();
+		
+			/* check answer */
+			res = result.next();
+			if (!res) {
+				temp = false;
+			} else {
+				// make sure we only set as logged in if not already voted
+				if (decrypt(result.getString(1)).equals("F")) {  // they haven't already voted
+					freeStat.execute("UPDATE Roll SET voted = '" + encrypt("C") + "' WHERE name = '" + encrypt(name) + "' AND code = '" + encrypt(code) + "' AND pword = '" + encrypt(pword) + "'");
+				} else if (decrypt(result.getString(1)).equals("C")) {  // their vote hasn't been registered but they have logged in before
+					// no need to change database but write to log just in case
+					ERServer.NORM.info("DBase.PMcheckER(): User already tried to vote but not confirmed");
+				} else {  // otherwise they've already voted
+				}
+				results[0] = decrypt(result.getString(1));
+				results[1] = decrypt(result.getString(2));
+			}
+		
+			freeStat.close();
+			
+		} else {
+		
+			results[0] = "ERROR";
+			results[1] = "ERROR";
+			throw new Exception("DBase.PMcheckER() - invalid character(s) used");
+			
+		}
+		
+		return results;
+
+	} //EOF PMcheckER()
+
+
+	/**
+	 * A little processor intensive and might need tuning but this method finds the user
+	 * entry in the Electoral Roll that matches the received key and sets it has having
+	 * voted.
+	 *
+	 * @param akey String representing the voter's AuthKey
 	 * @returns    A boolean, true if the details match with one in the database
 	 */
-	protected static void confirmVoted(String akey) throws Exception {
+	protected static boolean confirmVoted(String akey) throws Exception {
 	
 		ResultSet results;
 		int count;
 		boolean carryon = true;
-		boolean res;
+		boolean res, retVal;
 	
 		/* Get a connection from the pool */
 		Connection freeConn = getConnection();
@@ -387,7 +454,7 @@ public class DBase {
 		count = freeStat.getUpdateCount();
 		results = freeStat.getResultSet();
 		if (!res) {  // if no result data records
-			throw new Exception("No voters were found who were confirmed as logged in");
+			carryon=true;
 		} else {  // otherwise calculate and find
 			while(results.next()&&carryon) {
 				if (akey.equals(AuthKey.build(decrypt(results.getString(1)),decrypt(results.getString(2)),decrypt(results.getString(3)),1))) {
@@ -400,14 +467,39 @@ public class DBase {
 		
 		// if we didn't find a match something is wrong
 		if (carryon) {
-			throw new Exception("No matching AuthKey found.");
+			retVal=false;
+		} else {
+			retVal=true;
 		}
 				
 		freeStat.close();
 		
+		return retVal;
+		
 	} //EOF confirmVoted()
 
 
+	/**
+	 * Using data from the PollManager sets a user as having voted
+	 *
+	 * @param name  String representing the voter's name
+	 * @param code  String representing the voter's vote-specific code
+	 * @param pword String representing the voter's password
+	 * @returns    A boolean, true if the details match with one in the database
+	 */
+	protected static void PMconfirmVoted(String name, String code, String pword) throws Exception {
+	
+		/* Get a connection from the pool */
+		Connection freeConn = getConnection();
+		Statement freeStat = freeConn.createStatement();
+			
+		freeStat.execute("UPDATE Roll SET voted = '" + encrypt("T") + "' WHERE name = '" + encrypt(name) + "' AND code = '" + encrypt(code) + "' AND pword = '" + encrypt(pword) + "'");
+
+		freeStat.close();
+		
+	} //EOF PMconfirmVoted()
+
+
 	/**
 	 * Goes through all Electoral Roll data to create keys made with key 1 and writes them
 	 * to a file for export.
@@ -418,10 +510,13 @@ public class DBase {
 		ERServer.NORM.info("Building all keys...");
 		
 		File keyFile = new File("rtserver.keys");
+		File testFile = new File("rtserver.test.keys"); //for test ballots
 		FileWriter out = new FileWriter(keyFile);
+		FileWriter t_out = new FileWriter(testFile);
 		ResultSet results;
 		int count;
-		boolean res;
+		boolean res, res2;
+		boolean test=false;
 		String temp;
 	
 		/* Get a connection from the pool */
@@ -440,20 +535,142 @@ public class DBase {
 		} else {  // otherwise do work
 			while(results.next()) {
 				// build + encrypt output
-				temp = AuthKey.build(decrypt(results.getString(1)),decrypt(results.getString(2)),decrypt(results.getString(3)),1);
-				temp = AuthKey.encrypt(temp,1);
-				out.write(temp + "\r\n");
+				if (decrypt(results.getString(4)).equals("B")) {
+					/* test ballot */
+					temp = AuthKey.build(decrypt(results.getString(1)),decrypt(results.getString(2)),decrypt(results.getString(3)),1);
+					temp = AuthKey.encrypt(temp,1);
+					t_out.write(temp + "\r\n");
+					// erase all sign that it was a test ballot
+					Connection freeConn2 = getConnection();
+					Statement freeStat2 = freeConn2.createStatement();
+					res2 = freeStat2.execute("UPDATE Roll SET voted = '" + encrypt("F") + "' WHERE name = '" + results.getString(1) + "' AND code = '" + results.getString(2) + "' AND pword = '" + results.getString(3) + "'");
+					freeStat2.close();
+					test=true;
+				} else {
+					/* normal user */
+					temp = AuthKey.build(decrypt(results.getString(1)),decrypt(results.getString(2)),decrypt(results.getString(3)),1);
+					temp = AuthKey.encrypt(temp,1);
+					out.write(temp + "\r\n");
+				}
 			}
 		}
 						
 		out.close();
+		t_out.close();
 		freeStat.close();
 
 		ERServer.NORM.info("Done! Wrote rtserver.keys for export.");
+		if (test) {
+			ERServer.NORM.info("Wrote rtserver.test.keys for export.");
+		}
 		
 	} //EOF makeAllKeys()
 
 
+	/**
+	 * Imports users from a CSV file and inserts them into ERServer database.
+	 *
+	 */
+	 protected static void importUsers() throws Exception {
+		int normal=0;
+		int test=0;
+		int line=0;
+		ResultSet result;
+		boolean res;
+		String inData = "";
+
+		ERServer.NORM.info("Importing users from erserver.users");
+	
+		BufferedReader in = new BufferedReader(new FileReader("erserver.users"));
+		
+		inData = in.readLine();
+
+		while (inData!=null) {
+			line++;
+			/* boundary check the data first */
+			// only if the data is alphanumeric, punctuation or spaces do we carry on
+			if (isSafe(inData)) {
+				// if a blank line then skip
+				if ((inData.equals(""))||(inData.equals(" "))||(inData.equals(null))) {
+					// do nothing
+					ERServer.NORM.info("importUsers - blank line skipped on line " + line);
+				} else {
+				
+					// parse to get seperate data fields
+					int i = 0;
+					String[] pp = new String[] {"", "", "", "", "", "", "", "", "", ""};
+	
+					StringTokenizer splitter = new StringTokenizer(inData, ",", false);
+
+					while (splitter.hasMoreTokens()) {
+						pp[i] = splitter.nextToken();
+						i++;
+					}
+					
+					String name = pp[0];
+					String code = pp[1];
+					String pword = pp[2];
+					String status = pp[3];
+					String vote_where = pp[4];
+
+					// validity checks
+					switch(status.charAt(0)) {
+						case 'F': break; // normal voter
+						case 'B': break; // test ballot
+						default : throw new Exception("importUsers - bad voter status in record, only F or B allowed. On line " + line);
+					}
+
+					switch(vote_where.charAt(0)) {
+						case 'I': break;  // internt
+						case 'M': break;  // mail (postal)
+						case 'P': break;  // polling station
+						case 'O': break;  // other
+						default : throw new Exception("importUsers - bad vote_where in record, only I,M,P or O allowed. On line " + line);
+					}
+					
+					/* search DB for duplicates */
+					
+					// Get a connection from the pool
+					Connection freeConn = getConnection();
+					Statement freeStat = freeConn.createStatement();
+					res = freeStat.execute("SELECT voted FROM Roll WHERE name = '" + encrypt(name) + "' AND code = '" + encrypt(AuthSys.makeDigest(code)) + "' AND pword = '" + encrypt(AuthSys.makeDigest(pword)) + "'");
+					result = freeStat.getResultSet();
+		
+					// check answer 
+					res = result.next();
+					if (!res) {
+						doSQL("INSERT INTO Roll VALUES ('" + encrypt(name) + "', '" + encrypt(AuthSys.makeDigest(code)) + "', '" + encrypt(AuthSys.makeDigest(pword)) + "', '" + encrypt(status) + "', '" + encrypt(vote_where) + "','','');");
+					} else {
+						// we have a duplicate so inform and skip
+						ERServer.NORM.info("importUsers - record on line " + line + " already exists in DB.");
+					}
+
+					freeStat.close();
+
+					/* ratio count */
+					if (status.equals("B")) {
+						// Test Ballot
+						test++;
+					} else {
+						// Normal user
+						normal++;
+					}
+				}
+					inData = in.readLine();
+			} else {
+				throw new Exception("importUsers - invalid character(s) used on line " + line);
+			}
+		}
+	 
+	 	float proportions = new Float(test).floatValue() / (new Float(test).floatValue() + new Float(normal).floatValue());
+	 	if (proportions>0.29) {
+	 		ERServer.NORM.warn("Proportion of Test Ballots is rather high: " + new Float(proportions * 100).toString() + "%");
+	 	}
+		ERServer.NORM.info("Import complete.");
+		
+	 } //eof importUsers
+
+
 	/**
 	 * executes the SQL command sent as a parameter and returns the result to DB Console.
 	 *
@@ -490,7 +707,7 @@ public class DBase {
 				code = data.substring((i+1),t);									
 				pword = data.substring(t+1);
 
-				sqlCommand = "INSERT INTO Roll VALUES ('" + encrypt(name) + "', '" + encrypt(AuthSys.makeDigest(code)) + "', '" + encrypt(AuthSys.makeDigest(pword)) + "', '" + encrypt("F") + "');";
+				sqlCommand = "INSERT INTO Roll VALUES ('" + encrypt(name) + "', '" + encrypt(AuthSys.makeDigest(code)) + "', '" + encrypt(AuthSys.makeDigest(pword)) + "', '" + encrypt("F") + "', '" + encrypt("I") + "','','');";
 			}			
 		
 			/* boundary check the data first */
@@ -514,8 +731,8 @@ public class DBase {
 					ERServer.frame2.showInfo("-DONE-");
 				} else {  // otherwise show results
 					while(results.next()) {
-						ERServer.frame2.showInfo(decrypt(results.getString(1)) + "  " + decrypt(results.getString(2)) + "  " + decrypt(results.getString(3)) + "  " + decrypt(results.getString(4)));
-					}  //FIXME: Improve flexibility as assumes four columns of results
+						ERServer.frame2.showInfo(decrypt(results.getString(1)) + "  " + decrypt(results.getString(2)) + "  " + decrypt(results.getString(3)) + "  " + decrypt(results.getString(4)) + "  " + decrypt(results.getString(5)) + "  " + decrypt(results.getString(6)) + "  " + decrypt(results.getString(7)));
+					}  //FIXME: Improve flexibility as assumes seven columns of results
 					ERServer.frame2.showInfo("-DONE-");
 				}
       
