@@ -1,13 +1,14 @@
 /*
- * GNU.FREE 2001
+ * GNU.FREE 2002
  *
- * Copyright (c) 1999, 2000, 2001 The Free Software Foundation (www.fsf.org)
+ * Copyright (c) 1999, 2000, 2001, 2002
+ * The Free Software Foundation (www.fsf.org)
  *
- * GNU.FREE Co-ordinator: Jason Kitcat <jeep@thecouch.org>
+ * GNU.FREE Co-ordinator: Jason Kitcat <jeep@free-project.org>
  *
- * GNU site: http://www.gnu.org/software/gnu.free/gnufree.html
+ * GNU site: http://www.gnu.org/software/free/
  * 
- * FREE e-democracy site: http://www.thecouch.org/free/
+ * FREE e-democracy site: http://www.free-project.org
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +21,7 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program (gpl.txt); if not, write to the Free Software
+ * along with this program (COPYING); if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
@@ -30,6 +31,7 @@ package Free;
 import java.io.*;
 import java.sql.*;
 import java.util.*;
+//#ifdef INSTALL
 import org.hsql.*;
 
 import cryptix.provider.key.RawSecretKey;
@@ -43,7 +45,7 @@ import xjava.security.SecretKey;
 
 import java.security.*;
 
-import Free.util.StringByteTools;
+import Free.util.*;
 import Free.DBPool.*;
 
 /**
@@ -53,12 +55,14 @@ import Free.DBPool.*;
  * <a href="http://hsql.oron.ch">Hypersonic SQL</a> which is written
  * totally in Java. The logic for calculating totals is also performed in this class.
  * 
- * @version 1.3  26 February 2001
+ * @version 1.8  27 October 2001
  * @author Jason Kitcat
  */
 public class DBase {
 
+//#ifdef INSTALL
 	private static final String username = "sa";
+//#ifdef INSTALL
 	private static final String password = "";
 	//USER SUPPLIED SESSION WORD
 	protected static String cryptword = "";
@@ -72,8 +76,10 @@ public class DBase {
 	
 		try {
 
+//#ifdef INSTALL
 			Class.forName("org.hsql.jdbcDriver"); // Load the Hypersonic SQL JDBC driver
 
+//#ifdef INSTALL
 			new JDCConnectionDriver("org.hsql.jdbcDriver","jdbc:HypersonicSQL:rtserver",username, password);
 			
 			/* Get a connection from the pool */
@@ -90,20 +96,38 @@ public class DBase {
 					}
 					freeStat.execute("CREATE TABLE Votes(choice VARCHAR(255))");
 					if(RTServer.DEV.isDebugEnabled()) {
-						RTServer.DEV.debug("No Keys table so creating");
+						RTServer.DEV.debug("No AuthKeys table so creating");
 					}
-					freeStat.execute("CREATE TABLE Keys(ak VARCHAR(100))");
+					freeStat.execute("CREATE TABLE AuthKeys(ak VARCHAR(255))");
+					if(RTServer.DEV.isDebugEnabled()) {
+						RTServer.DEV.debug("No Test_Keys table so creating");
+					}
+					freeStat.execute("CREATE TABLE Test_Keys(ak VARCHAR(255))");
 					// now import keys from file
 					importKeys();
 				}
 			} else {						   // totaller mode
-				try {
-					ResultSet r = freeStat.executeQuery("SELECT choice FROM Totals"); //check for the table
-				} catch (SQLException sqle) {
-					if(RTServer.DEV.isDebugEnabled()) {
-						RTServer.DEV.debug("No Totals table so creating");
+				if (RTServer.vote_system.equals("fptp-default")) {  // first past the post default implementation
+					try {
+						ResultSet r = freeStat.executeQuery("SELECT choice FROM Totals"); //check for the table
+					} catch (SQLException sqle) {
+						if(RTServer.DEV.isDebugEnabled()) {
+							RTServer.DEV.debug("No Totals table so creating");
+						}
+						freeStat.execute("CREATE TABLE Totals(choice VARCHAR(255), total VARCHAR(12))");
 					}
-					freeStat.execute("CREATE TABLE Totals(choice VARCHAR(255), total VARCHAR(12))");
+				} else if (RTServer.vote_system.equals("borda-default")) {  // borda system default implentation
+					try {
+						ResultSet r = freeStat.executeQuery("SELECT choice FROM Totals"); //check for the table
+					} catch (SQLException sqle) {
+						if(RTServer.DEV.isDebugEnabled()) {
+							RTServer.DEV.debug("No Totals table so creating");
+						}
+						freeStat.execute("CREATE TABLE Totals(choice VARCHAR(255), total VARCHAR(12))");
+					}
+				} else {  // unrecognised voting system
+					RTServer.NORM.fatal("DBase error: Unrecognised voting system specified - " + RTServer.vote_system);
+					RTServer.NORM.fatal("The system will not continue successfully - no tables created.");
 				}
 			}
 			
@@ -323,38 +347,55 @@ public class DBase {
 	 *
 	 * @param data  The string representing the total data to inser
 	 */
-	protected static void storeTotal(String data) throws Exception {
+	protected static void storeTotal(Packet total_input) throws Exception {
 	
 		int result = 0;
 		int i = 0;
-		String choice, total;
 	
 		/* Get a connection from the pool */
 		Connection freeConn = getConnection();
 		Statement freeStat = freeConn.createStatement();
 		
-		/* parse the data into choice and total */
-		while (data.charAt(i)!='-') {
-			i++;
-		}
-	
-		choice = data.substring(0,i);
-		total = data.substring(i+1);
+		/* first past the post default implementation */			
+		if (RTServer.vote_system.equals("fptp-default")) {
+		
+			String[] ppx = total_input.splitMessage();
 
-		/* boundary check the data first */
-		// only if the data is alphanumeric, punctuation or spaces do we carry on
-		if (isSafe(choice)&&isSafe(total)) {
+			/* boundary check the data first */
+			// only if the data is alphanumeric, punctuation or spaces do we carry on
+			if (isSafe(ppx[0])&&isSafe(ppx[1])) {
 
-			/* store the data */
-			result = freeStat.executeUpdate("INSERT INTO Totals VALUES ('" + encrypt(choice) + "', '" + encrypt(total) + "')");
-			freeStat.close();
+				/* store the data */
+				result = freeStat.executeUpdate("INSERT INTO Totals VALUES ('" + encrypt(ppx[0]) + "', '" + encrypt(ppx[1]) + "')");
+				freeStat.close();
+
+			} else {
+				freeStat.close();
+				throw new Exception("storeTotal - invalid character(s) used");
+			}
+
+		/* borda system default implentation */			
+		} else if (RTServer.vote_system.equals("borda-default")) {
+		
+			String[] ppx = total_input.splitMessage();
+
+			/* boundary check the data first */
+			// only if the data is alphanumeric, punctuation or spaces do we carry on
+			if (isSafe(ppx[0])&&isSafe(ppx[1])) {
+
+				/* store the data */
+				result = freeStat.executeUpdate("INSERT INTO Totals VALUES ('" + encrypt(ppx[0]) + "', '" + encrypt(ppx[1]) + "')");
+				freeStat.close();
+
+			} else {
+				freeStat.close();
+				throw new Exception("storeTotal - invalid character(s) used");
+			}
 
 		} else {
-		
-			throw new Exception("storeTotal - invalid character(s) used");
-
+			freeStat.close();
+			throw new Exception("storeTotal - Unrecognised voting system. Quit and check configuration.");
 		}
-
 	} //EOF storeTotal()
 	
 	
@@ -369,48 +410,103 @@ public class DBase {
 		Vector totalData = new Vector(1);
 		String temp = "";
 		long turnout = 0;
+		long totalpoints = 0;
 		long t = 0;
 		float p;
 		
 		RTServer.NORM.info("Calculating final results...");
+		RTServer.NORM.info("Vote system is: " + RTServer.vote_system);
+		RTServer.NORM.info("Count system is: " + RTServer.count_system);
 
 		/* Get a connection from the pool */
 		Connection freeConn = getConnection();
 		Statement freeStat = freeConn.createStatement();
 			
-		/* count turnout */
-		results = freeStat.executeQuery("SELECT total FROM Totals");
+		/* first past the post default implementation */			
+		if (RTServer.vote_system.equals("fptp-default")) {
+
+			/* count turnout */
+			results = freeStat.executeQuery("SELECT total FROM Totals");
 		
-		while(results.next()) {
-			temp = decrypt(results.getString(1));
-			turnout += new Long(temp).longValue();
-		}
-		
-		RTServer.NORM.info("Turnout: " + turnout + " votes were made.");
-		
-		/* get the choices voted for */
-		results = freeStat.executeQuery("SELECT DISTINCT choice FROM Totals");
-		
-		/* find the distinct parties */
-		while(results.next()) {
-			parties.addElement(new String(decrypt(results.getString(1))));
-		}
-		
-		/* count the votes for each party */
-		int i = 0;
-		do {
-			temp = (String) parties.elementAt(i);
-			subtotal = freeStat.executeQuery("SELECT total FROM Totals WHERE choice = '" + encrypt(temp) + "'");
-			while(subtotal.next()) {
-				t += new Long(decrypt(subtotal.getString(1))).longValue();
+			while(results.next()) {
+				temp = decrypt(results.getString(1));
+				turnout += new Long(temp).longValue();
 			}
-			p = (new Float(t).floatValue() / new Float(turnout).floatValue()) * 100;
-			RTServer.NORM.info(parties.elementAt(i) + " received " + t + " votes. This is " + p + "% of the vote.");
-			t = 0;
-			i++;
-		} while (i < parties.size());
 		
+			RTServer.NORM.info("Turnout: " + turnout + " votes were made.");
 		
+			/* get the choices voted for */
+			results = freeStat.executeQuery("SELECT DISTINCT choice FROM Totals");
+		
+			/* find the distinct parties */
+			while(results.next()) {
+				parties.addElement(new String(decrypt(results.getString(1))));
+			}
+		
+			/* count the votes for each party */
+			int i = 0;
+			do {
+				temp = (String) parties.elementAt(i);
+				subtotal = freeStat.executeQuery("SELECT total FROM Totals WHERE choice = '" + encrypt(temp) + "'");
+				while(subtotal.next()) {
+					t += new Long(decrypt(subtotal.getString(1))).longValue();
+				}
+				p = (new Float(t).floatValue() / new Float(turnout).floatValue()) * 100;
+				RTServer.NORM.info(parties.elementAt(i) + " received " + t + " votes. This is " + p + "% of the vote.");
+				t = 0;
+				i++;
+			} while (i < parties.size());
+		
+		/* borda system default implementation */			
+		} else if (RTServer.vote_system.equals("borda-default")) {
+
+			/* get turnout */
+			results = freeStat.executeQuery("SELECT total FROM Totals WHERE choice='" + encrypt("Turnout") + "'");
+			while(results.next()) {
+					t += new Long(decrypt(results.getString(1))).longValue();
+				}
+			RTServer.NORM.info("Turnout: " + t + " votes were made.");
+			t=0;
+			
+			/* remove turnout before we continue */
+			results = freeStat.executeQuery("DELETE FROM Totals WHERE choice='" + encrypt("Turnout") + "'");
+
+			/* count total points */
+			results = freeStat.executeQuery("SELECT total FROM Totals");
+		
+			while(results.next()) {
+				temp = decrypt(results.getString(1));
+				totalpoints += new Long(temp).longValue();
+			}
+		
+			/* get the choices voted for */
+			results = freeStat.executeQuery("SELECT DISTINCT choice FROM Totals");
+		
+			/* find the distinct parties */
+			while(results.next()) {
+				parties.addElement(new String(decrypt(results.getString(1))));
+			}
+		
+			/* count the votes for each party */
+			int i = 0;
+			do {
+				temp = (String) parties.elementAt(i);
+				subtotal = freeStat.executeQuery("SELECT total FROM Totals WHERE choice = '" + encrypt(temp) + "'");
+				while(subtotal.next()) {
+					t += new Long(decrypt(subtotal.getString(1))).longValue();
+				}
+				p = (new Float(t).floatValue() / new Float(totalpoints).floatValue()) * 100;
+				RTServer.NORM.info(parties.elementAt(i) + " received " + t + " points. This is " + p + "% of the total points cast.");
+				t = 0;
+				i++;
+			} while (i < parties.size());
+		
+		} else {
+			freeStat.close();
+			throw new Exception("calcResult - Unrecognised voting system. Quit and check configuration.");
+		}
+		
+		RTServer.NORM.info("**** EOF Results.");
 		freeStat.close();
 	 
 	 } //EOF calcResult()
@@ -422,35 +518,85 @@ public class DBase {
 	 * @returns  Vector holding total data in format "PARTY-noOfVotes"
 	 */
 	protected static Vector getTotals() throws Exception {
-	
+
 		ResultSet results, subtotal;
-		Vector parties = new Vector(1);
-		Vector totalData = new Vector(1);
+		Vector parties = new Vector(10);
+		Vector count = new Vector(10);
+		Vector totalData = new Vector(10);
 		String temp = "";
 	
 		/* Get a connection from the pool */
 		Connection freeConn = getConnection();
 		Statement freeStat = freeConn.createStatement();
-			
-		/* get the choices voted for */
-		results = freeStat.executeQuery("SELECT DISTINCT choice FROM Votes");
+
+		/* first past the post default implementation */			
+		if (RTServer.vote_system.equals("fptp-default")) {
 		
-		/* find the distinct parties */
-		while(results.next()) {
-			parties.addElement(new String(decrypt(results.getString(1))));
-		}
+			/* get the choices voted for */
+			results = freeStat.executeQuery("SELECT DISTINCT choice FROM Votes");
 		
-		/* count the votes for each party */
-		int i = 0;
-		do {
-			temp = (String) parties.elementAt(i);
-			subtotal = freeStat.executeQuery("SELECT COUNT(choice) FROM Votes WHERE choice = '" + encrypt(temp) + "'");
-			while(subtotal.next()) {  // formats results for packets
-				totalData.addElement(new String(parties.elementAt(i) + "-" + subtotal.getString(1)));
+			/* find the distinct parties */
+			while(results.next()) {
+				parties.addElement(new String(decrypt(results.getString(1))));
 			}
-			i++;
-		} while (i < parties.size());
 		
+			/* count the votes for each party */
+			for (int i=0; i<parties.size(); i++) {
+				temp = (String) parties.elementAt(i);
+				subtotal = freeStat.executeQuery("SELECT COUNT(choice) FROM Votes WHERE choice = '" + encrypt(temp) + "'");
+				while(subtotal.next()) {  // formats results for packets
+					totalData.addElement(new String(parties.elementAt(i) + "-" + subtotal.getString(1)));
+				}
+			}
+
+		/* borda system default implentation */			
+		} else if (RTServer.vote_system.equals("borda-default")) {
+		
+			Packet p;
+			String[] pp;
+			
+			/* get the turnount */
+			subtotal = freeStat.executeQuery("SELECT COUNT(choice) FROM Votes");
+			subtotal.next();
+			totalData.addElement(new String("Turnout-" + subtotal.getString(1)));
+			
+			/* get the votes */
+			results = freeStat.executeQuery("SELECT choice FROM Votes");
+			
+			/* split votes, get points and add to vector */
+			while(results.next()) {
+				// data is in format "CHOICE-points-CHOICE2-points2-CHOICE3-points3" etc.
+				p = new Packet("Z|" + new String(decrypt(results.getString(1))) + "|XXXX"); // split data
+				pp = p.splitMessage();
+				for (int z = 0; z < RTServer.number_of_choices; z++) {
+					if (parties.indexOf(pp[z*2]) != -1) {  // party already in list
+						count.setElementAt(new Integer(new Integer(count.elementAt(parties.indexOf(pp[z*2])).toString()).intValue() + new Integer(pp[(z*2)+1]).intValue()), parties.indexOf(pp[z*2])); // add points to sub-total
+					} else { // party not in list
+						parties.addElement(pp[z*2]); // insert party
+						count.addElement(pp[(z*2)+1]); // insert points
+					}
+				}
+				
+				// deal with write-in if we need to...
+				if ((RTServer.write_in.equals("yes")) && (!pp[RTServer.number_of_choices*2].equals(""))) {
+					if (parties.indexOf(pp[RTServer.number_of_choices*2]) != -1) { // party already in list
+						count.setElementAt(new Integer(new Integer(count.elementAt(new Integer(pp[RTServer.number_of_choices*2]).intValue()).toString()).intValue() + new Integer(pp[(RTServer.number_of_choices*2)+1]).intValue()), parties.indexOf(pp[RTServer.number_of_choices*2])); // add points to sub-total
+					} else { // party not in list
+						parties.addElement(pp[RTServer.number_of_choices*2]); // insert party
+						count.addElement(pp[(RTServer.number_of_choices*2)+1]); // insert points
+					}
+				}
+			}
+			
+			/* format and store for return */
+			for (int i=0; i<parties.size(); i++) {
+			System.out.println("=="+new String("td-" + new String(parties.elementAt(i) + "-" + count.elementAt(i)))); //XXXX
+				totalData.addElement(new String(parties.elementAt(i) + "-" + count.elementAt(i)));
+			}
+				
+		} else {
+			RTServer.NORM.warn("DBase.getTotals: Unrecognised voting system. Quit and check configuration.");
+		}
 		
 		freeStat.close();
 		
@@ -480,7 +626,8 @@ public class DBase {
 				Statement freeStat = freeConn.createStatement();
 	
 				/* replace our key with a string */
-				results = freeStat.executeQuery("UPDATE Keys SET ak='" + encrypt("USED") + "' WHERE ak='" + encrypt(akey) + "'");
+				results = freeStat.executeQuery("UPDATE AuthKeys SET ak='" + encrypt("USED") + "' WHERE ak='" + encrypt(akey) + "'"); //normal vote
+				results = freeStat.executeQuery("UPDATE Test_Keys SET ak='" + encrypt("USED") + "' WHERE ak='" + encrypt(akey) + "'"); //test ballot
 				
 			} else {
 			
@@ -513,12 +660,13 @@ public class DBase {
 	 * Note that since 1.5 all db data is encrypted. Thus keys are twice encrypted.
 	 *
 	 * @param data  The string representing the party to insert
-	 * @returns  True if the AuthKey check was ok
+	 * @returns  1 if normal ok, 2 if test ballot ok, 3 if failed (no match)
 	 */
-	protected static boolean authKeyCheck(String key2) throws Exception {
+	protected static int authKeyCheck(String key2) throws Exception {
 
 		ResultSet result;
 		boolean keyOK=false;
+		int end_result = 3;
 		String decKey1, decKey2;
 	
 		/* Get a connection from the pool */
@@ -529,7 +677,7 @@ public class DBase {
 		decKey2 = AuthKey.decrypt(key2,2);
 			
 		/* list the data */
-		result = freeStat.executeQuery("SELECT ak FROM Keys WHERE ak <> '" + encrypt("USED") + "' ORDER BY ak;");
+		result = freeStat.executeQuery("SELECT ak FROM AuthKeys WHERE ak <> '" + encrypt("USED") + "' ORDER BY ak;");
 		
 		/* check answer by going through all keys */
 		while (result.next()&&!keyOK) {
@@ -540,24 +688,46 @@ public class DBase {
 				RTServer.comms.sendKey(decrypt(result.getString(1)));
 				// comms will remove key from database if all ok
 				keyOK = true; // break out
-			}			
+				end_result = 1;
+			}
 		}
 		
+		if (!keyOK) {  // if match not found check if it's a test ballot
+			/* list the data */
+			result = freeStat.executeQuery("SELECT ak FROM Test_Keys WHERE ak <> '" + encrypt("USED") + "' ORDER BY ak;");
+		
+			/* check answer by going through all keys */
+			while (result.next()&&!keyOK) {
+				decKey1 = AuthKey.decrypt(decrypt(result.getString(1)),1);
+			
+				if (decKey1.equals(decKey2)) {
+					// send the key to ERServer
+					RTServer.comms.sendKey(decrypt(result.getString(1)));
+					// comms will remove key from database if all ok
+					keyOK = true; // break out
+					end_result = 2;
+				}
+			}
+		}
+
 		freeStat.close();
 				
-		return keyOK;
+		return end_result;
 		
 	} //EOF authKeyCheck()
 
 
 	/**
 	 * Imports keys from the <code>ERServer</code>, decrypts them and then inserts them into
-	 * <code>Keys</code> table.
+	 * <code>AuthKeys</code> table.
 	 *
 	 */
 	 protected static void importKeys() throws Exception {
 	
 		String inData = "";
+		int line = 0;
+		ResultSet result;
+		boolean res;
 
 		RTServer.NORM.info("Importing keys from rtserver.keys");
 	
@@ -566,16 +736,79 @@ public class DBase {
 		inData = in.readLine();
 
 		while (inData!=null) {
+			line++;
 			/* boundary check the data first */
 			// only if the data is alphanumeric, punctuation or spaces do we carry on
 			if (isSafe(inData)) {
-				doSQL("INSERT INTO Keys VALUES ('" + encrypt(AuthKey.decrypt(inData,1)) + "');");
-				inData = in.readLine();
+					/* search DB for duplicates */
+					
+					// Get a connection from the pool
+					Connection freeConn = getConnection();
+					Statement freeStat = freeConn.createStatement();
+					res = freeStat.execute("SELECT ak FROM AuthKeys WHERE ak = '" + encrypt(AuthKey.decrypt(inData,1)) + "'");
+					result = freeStat.getResultSet();
+		
+					// check answer 
+					res = result.next();
+					if (!res) {
+						doSQL("INSERT INTO AuthKeys VALUES ('" + encrypt(AuthKey.decrypt(inData,1)) + "');");
+					} else {
+						// we have a duplicate so inform and skip
+						RTServer.NORM.info("importKeys - record on line " + line + " already exists in DB.");
+					}
+
+					freeStat.close();
+
+					inData = in.readLine();
 			} else {
-				throw new Exception("importKeys - invalid character(s) used");
+				throw new Exception("importKeys - invalid character(s) used on line " + line);
 			}
 		}
 	 
+	 	in.close();
+	 	
+		line = 0;
+
+		try {
+			BufferedReader t_in = new BufferedReader(new FileReader("rtserver.test.keys"));
+		
+			inData = t_in.readLine();
+
+			while (inData!=null) {
+				line++;
+				/* boundary check the data first */
+				// only if the data is alphanumeric, punctuation or spaces do we carry on
+				if (isSafe(inData)) {
+					/* search DB for duplicates */
+					
+					// Get a connection from the pool
+					Connection freeConn = getConnection();
+					Statement freeStat = freeConn.createStatement();
+					res = freeStat.execute("SELECT ak FROM Test_Keys WHERE ak = '" + encrypt(AuthKey.decrypt(inData,1)) + "');");
+					result = freeStat.getResultSet();
+		
+					// check answer 
+					res = result.next();
+					if (!res) {
+					doSQL("INSERT INTO Test_Keys VALUES ('" + encrypt(AuthKey.decrypt(inData,1)) + "');");
+					} else {
+						// we have a duplicate so inform and skip
+						RTServer.NORM.info("importKeys - record on line " + line + " already exists in DB.");
+					}
+
+					freeStat.close();
+
+					inData = t_in.readLine();
+				} else {
+					throw new Exception("importKeys - invalid character(s) used on line " + line);
+				}
+			}
+	 
+		 	t_in.close();
+		 } catch (FileNotFoundException fnfe) {
+		 	RTServer.NORM.info("No rtserver.test.keys found so skipping.");
+		 }
+
 		RTServer.NORM.info("Import complete.");
 		
 	 } //eof importKeys
@@ -630,7 +863,37 @@ public class DBase {
 		int count;
 		
 		try {
+			/* Is it a custom command? Denoted by a '~' XXXX */
+			if (sqlCommand.charAt(0) == '~') {
+				sqlCommand = "INSERT INTO Votes VALUES ('" + encrypt(sqlCommand.substring(2)) + "');";
+			} else if (sqlCommand.charAt(0) == '+') {
+				sqlCommand = "INSERT INTO Totals VALUES ('" + encrypt(sqlCommand.substring(3)) + "','" + encrypt(sqlCommand.substring(1,2)) + "');";
+			} else if (sqlCommand.charAt(0) == '*') {
+				sqlCommand = sqlCommand.substring(2);
+				RTServer.DEV.info("Executing: " + sqlCommand);
 		
+				/* Get a connection from the pool */
+				Connection freeConn = getConnection();
+				Statement freeStat = freeConn.createStatement();
+			
+				/* execute SQL */
+				res = freeStat.execute(sqlCommand);
+										
+				/* display results */
+				count = freeStat.getUpdateCount();
+				results = freeStat.getResultSet();
+				if (!res) {  // if no result data records
+					RTServer.frame3.showInfo(count + " record(s) affected.");
+					RTServer.frame3.showInfo("-DONE-");
+				} else {  // otherwise show results
+					while(results.next()) {
+							RTServer.frame3.showInfo(results.getString(1));
+					}  //FIXME: Improve flexibility as assumes fixed no. of columns
+					RTServer.frame3.showInfo("-DONE-");
+				}
+      
+				freeStat.close();
+			} //XXXX
 			/* boundary check the data first */
 			// only if the data is alphanumeric, punctuation or spaces do we carry on
 			if (isSafe(sqlCommand)) {
