@@ -1,13 +1,14 @@
 /*
- * GNU.FREE 2001
+ * GNU.FREE 2002
  *
- * Copyright (c) 1999, 2000, 2001 The Free Software Foundation (www.fsf.org)
+ * Copyright (c) 1999, 2000, 2001, 2002
+ * The Free Software Foundation (www.fsf.org)
  *
- * GNU.FREE Co-ordinator: Jason Kitcat <jeep@thecouch.org>
+ * GNU.FREE Co-ordinator: Jason Kitcat <jeep@free-project.org>
  *
- * GNU site: http://www.gnu.org/software/gnu.free/gnufree.html
+ * GNU site: http://www.gnu.org/software/free/
  * 
- * FREE e-democracy site: http://www.thecouch.org/free/
+ * FREE e-democracy site: http://www.free-project.org
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +21,7 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program (gpl.txt); if not, write to the Free Software
+ * along with this program (COPYING); if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
@@ -58,7 +59,7 @@ public class Intro extends Frame
 	protected Intro()
 	{
 
-		setTitle("FREE: Settings");
+		setTitle("GNU.FREE: Settings");
 		jRadioButton1 = new Checkbox("Regional Server", group, false);
 		jRadioButton2 = new Checkbox("Totaller Server", group, false);
 		jButton1.setLabel("OK");
@@ -69,7 +70,7 @@ public class Intro extends Frame
 		jLabel3.setText("You've missed one!");
 		jLabel3.setVisible(false);
 	
-		FreePanel scrollPanel = new FreePanel("FREE: Settings");
+		FreePanel scrollPanel = new FreePanel("GNU.FREE: Settings");
 		scrollPanel.setInsets(3, 3, 3, 3);
 		
 		scrollPanel.addComponent( 1, 0, 1, 2, 0, 0, GridBagConstraints.BOTH, 
