@@ -1,13 +1,14 @@
 /*
- * GNU.FREE 2001
+ * GNU.FREE 2002
  *
- * Copyright (c) 1999, 2000, 2001 The Free Software Foundation (www.fsf.org)
+ * Copyright (c) 1999, 2000, 2001, 2002
+ * The Free Software Foundation (www.fsf.org)
  *
- * GNU.FREE Co-ordinator: Jason Kitcat <jeep@thecouch.org>
+ * GNU.FREE Co-ordinator: Jason Kitcat <jeep@free-project.org>
  *
- * GNU site: http://www.gnu.org/software/gnu.free/gnufree.html
+ * GNU site: http://www.gnu.org/software/free/
  * 
- * FREE e-democracy site: http://www.thecouch.org/free/
+ * FREE e-democracy site: http://www.free-project.org
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +21,7 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program (gpl.txt); if not, write to the Free Software
+ * along with this program (COPYING); if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
@@ -30,6 +31,8 @@ package Free;
 import java.io.*;
 import java.net.*;
 
+import Free.util.*;
+
 /**
  * TCPClient allows <code>RTServer</code> to connect as a client to
  * a totaller server when the ballot has closed.
@@ -38,11 +41,22 @@ import java.net.*;
  * with errors, all data is passed to <code>ClientProtocol</code> for
  * for processing.
  *
- * @version 0.9 26 February 2001
+ * @version 1.2 30 August 2001
  * @author Jason Kitcat
  */
 public class TCPClient implements Runnable {
 
+	String message="";
+	int vectIndex=0;
+	
+	/**
+	 * constructor
+	 */
+	 public TCPClient(String m, int v) {
+	 	message=m;
+	 	vectIndex=v;
+	 }
+	 
 	/**
 	 * run() delivers a packet to the server whose DNS address is chosen
 	 * 
@@ -51,7 +65,7 @@ public class TCPClient implements Runnable {
 	
 		String serverName="";
 		String packetMsg;
-		int port;
+		int port=0;
 		Socket freeSocket = null;
 		PrintWriter out = null;
 		BufferedReader in = null;
@@ -59,20 +73,23 @@ public class TCPClient implements Runnable {
 		/* get data */
 		if (RTServer.comms.getType()=='T') {
 			serverName = RTServer.comms.T_address;
+			port = RTServer.comms.freeRTPort;
 		} else if (RTServer.comms.getType()=='D') {
 			serverName = RTServer.comms.ER_address;
+			port = RTServer.comms.freePort;
 		} else if (RTServer.comms.getType()=='K') {
 			serverName = RTServer.comms.ER_address;
+			port = RTServer.comms.freePort;
 		} else if (RTServer.comms.getType()=='Q') {
 			serverName = RTServer.comms.ER_address;
+			port = RTServer.comms.freePort;
 		} else {
 			// let's get defensive
 			RTServer.NORM.warn("Unknown packet type");
 			RTServer.carryOn = false;
 		}
 		
-		packetMsg = RTServer.comms.getMessage() + "\r\n";
-		port = RTServer.comms.freePort;
+		packetMsg = message + "\r\n";
 		
 		/* send packet */
 		try {
@@ -100,7 +117,7 @@ public class TCPClient implements Runnable {
 		}
 		
 		String inputData = "NONE";
-		String outputData = "NONE";
+		String[] outputData = new String[] {" ","NONE"};
 		
 		/* read response */
 		try {
@@ -113,24 +130,30 @@ public class TCPClient implements Runnable {
 					
 					if (!inputData.equals("")) { // check real data has arrived
 		
+						// decrypt data
+						String[] sess_data = RTServer.comms.getSession(vectIndex);
+						inputData = RSAEncrypt.blowDecrypt(sess_data[5], inputData);
+						RTServer.comms.setSession(vectIndex,sess_data[5],sess_data[0],sess_data[1],sess_data[2],sess_data[3],new Integer(sess_data[4]).intValue(),sess_data[6]); // we need to setSession() as getSession() empties data
+						
 						if(RTServer.DEV.isDebugEnabled()) {
 							RTServer.DEV.debug("Received: " + inputData);
 						}
-						outputData = ClientProtocol.process(inputData);
+						// now process
+						outputData = ClientProtocol.process(inputData, vectIndex);
 						
-						if ((outputData.equals("DONE"))|(outputData.equals("ERROR"))) {
+						if ((outputData[1].equals("DONE"))|(outputData[1].equals("ERROR"))) {
 						
 							break;
 							
-						} else if (outputData.charAt(0)=='X') {
+						} else if (outputData[0].charAt(0)=='X') {
 						
-							out.println(outputData);
+							out.println(outputData[1]);
 							
 							break;
 							
 						} else {
 						
-							out.println(outputData);
+							out.println(outputData[1]);
 							
 						}
 						
@@ -153,12 +176,12 @@ public class TCPClient implements Runnable {
 				RTServer.NORM.error("Error shutting connection: " + e.getMessage());
 			}
 			
-			RTServer.comms.timer.stopThread();
-			RTServer.comms.setFromServer(outputData);
+			((TimeOutThread) RTServer.comms.threadTimeOut.elementAt(vectIndex)).stopThread(); //stop timeout
+			RTServer.comms.setFromServer(outputData[1]);
+			RTServer.comms.threadTimeOut.setElementAt("",vectIndex);  //clear out threads
+			RTServer.comms.threadVect.setElementAt("",vectIndex);
 		}
 
-		RTServer.comms.timer.stopThread();
-		
 	} //EOF run
 	
 } //EOF TCPClient
\ No newline at end of file
