@@ -1,13 +1,14 @@
 /*
- * GNU.FREE 2001
+ * GNU.FREE 2002
  *
- * Copyright (c) 1999, 2000, 2001 The Free Software Foundation (www.fsf.org)
+ * Copyright (c) 1999, 2000, 2001, 2002
+ * The Free Software Foundation (www.fsf.org)
  *
- * GNU.FREE Co-ordinator: Jason Kitcat <jeep@thecouch.org>
+ * GNU.FREE Co-ordinator: Jason Kitcat <jeep@free-project.org>
  *
- * GNU site: http://www.gnu.org/software/gnu.free/gnufree.html
+ * GNU site: http://www.gnu.org/software/free/
  * 
- * FREE e-democracy site: http://www.thecouch.org/free/
+ * FREE e-democracy site: http://www.free-project.org
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +21,7 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program (gpl.txt); if not, write to the Free Software
+ * along with this program (COPYING); if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
@@ -31,6 +32,8 @@ import java.net.*;
 import java.io.*;
 import java.util.*;
 
+import Free.util.*;
+
 /**
  * The TCPServer Class opens a socket to listen for client connections
  * which, when received, are spun out into new threads to keep the listening
@@ -38,7 +41,7 @@ import java.util.*;
  *
  * The class is based on original code from "Java Threads" from O'Reilly.
  *
- * @version 0.9  9 February 2001
+ * @version 0.10  12 June 2001
  * @author Jason Kitcat
  */
 public class TCPServer implements Cloneable, Runnable {
@@ -135,10 +138,16 @@ public class TCPServer implements Cloneable, Runnable {
 					
 					if (!inputData.equals("")) { // check real data has arrived
 
+						/* decrypt data */
+						String[] tempiData = new String[] {"",""};
+						tempiData = RSAEncrypt.splitnDecrypt(RTServer.rt_private_key,inputData);
+						inputData = tempiData[1];
+						
 						if(RTServer.DEV.isDebugEnabled()) {
 							RTServer.DEV.debug("Received: " + inputData + " from " + data.toString());
 						}
-						outputData = ServerProtocol.process(inputData);
+						/* now process data */
+						outputData = ServerProtocol.process(inputData, tempiData[0]);
 						
 						if ((outputData.equals("DONE"))|(outputData.equals("ERROR"))) {
 						
