@@ -1,13 +1,14 @@
 /*
- * GNU.FREE 2001
+ * GNU.FREE 2002
  *
- * Copyright (c) 1999, 2000, 2001 The Free Software Foundation (www.fsf.org)
+ * Copyright (c) 1999, 2000, 2001, 2002
+ * The Free Software Foundation (www.fsf.org)
  *
- * GNU.FREE Co-ordinator: Jason Kitcat <jeep@thecouch.org>
+ * GNU.FREE Co-ordinator: Jason Kitcat <jeep@free-project.org>
  *
- * GNU site: http://www.gnu.org/software/gnu.free/gnufree.html
+ * GNU site: http://www.gnu.org/software/free/
  * 
- * FREE e-democracy site: http://www.thecouch.org/free/
+ * FREE e-democracy site: http://www.free-project.org
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +21,7 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program (gpl.txt); if not, write to the Free Software
+ * along with this program (COPYING); if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
@@ -33,29 +34,47 @@ import java.awt.event.*;
 import Free.awt.*;
 
 /**
- * Intro screen to explain to users what FREE does.
+ * Intro screen to explain to users what GNU.FREE does.
  *
- * @version 0.2 15 March 2000
+ * @version 0.3.5 12 April 2001
  * @author Jason Kitcat, Rajagopal C.V
  */
 public class FCFrame2 extends Frame 
 {
 
 	Label jLabel1 = new Label();
-	TextArea jTextPane1 = new TextArea();
+    TextView tv;
+	ScrollView sv;
+	Font f;
+	Font f2;
+	TextStyle normal;
+	TextStyle red;
+	TextStyle blue;
+	TextStyle green;
 	Button jButton1 = new Button();
 
 	protected FCFrame2() {
 
-		setTitle("FREE: Introduction");
-		jLabel1.setText("Introduction:");
-		jButton1.setLabel("OK");
+		// prepare textView
+		tv = new TextView(true);
+        sv = new ScrollView(tv);
+        f = new Font("Courier", Font.PLAIN, 12);
+        f2 = new Font("Courier", Font.BOLD, 12);
+        normal = new TextStyle(f, Color.black);
+        red = new TextStyle(f2, Color.red);
+        blue = new TextStyle(f, Color.blue);
+        green = new TextStyle(f, Color.green);
+        
+		// build frame
+		setTitle(FClient.messages.getString("intro_title"));
+		jLabel1.setText(FClient.messages.getString("intro"));
+		jButton1.setLabel(FClient.messages.getString("ok_button"));
 		
-		FreePanel scrollPanel = new FreePanel("Introduction:");
+		FreePanel scrollPanel = new FreePanel(FClient.messages.getString("intro"));
 		scrollPanel.setInsets(3, 3, 3, 3);
 		
 		scrollPanel.addComponent( 0, 0, 1, 2, 0, 0, GridBagConstraints.BOTH, 
-			1.0f, 1.0f, jTextPane1);
+			1.0f, 1.0f, sv);
 		FreePanel buttonPane = new FreePanel();
 		scrollPanel.addComponent( 1, 1, 1, 1, 0, 0, GridBagConstraints.BOTH, 
 			1.0f, 0.0f, jButton1);
@@ -89,13 +108,14 @@ public class FCFrame2 extends Frame
   
 	// Show an warning message (red, bold text)
 	protected void showError(String msg) {
-		showMsg(msg);
+		msg += "\n";
+		tv.append(msg, red);
 	}
 	
 	// Show a text message using the specified AttributeSet
 	protected void showMsg(String msg) {
 		msg += "\n";
-		jTextPane1.setText(jTextPane1.getText() + msg);
+		tv.append(msg, normal);
 	}
 
 	// Close the window when the close box is clicked
@@ -109,13 +129,11 @@ public class FCFrame2 extends Frame
 	}
 	
 	protected void thisWindowOpened(java.awt.event.WindowEvent e) {
-	
-		showInfo("Welcome to the FREE Voting System.\n\r\n\rThis system is specially designed to allow you to vote in full confidence. You can feel assured because FREE is designed for:\n\r\n\r- PRIVACY\n\rAt no time is a link ever made between who you are and what you have voted. Your choice is 100% private.\n\r\n\r- SECURITY\n\rFREE uses special security systems designed to prevent anybody voting multiple times or any third party from throwing the outcome of a vote.\n\r\n\r- RELIABILITY\n\rMany different computers are used by FREE, so that if one fails the whole vote won't be affected. FREE allows votes to be cheaper, faster and more accurate.\n\r\n\rThank you for voting - democracy needs you.\n\r\n\r");
-					
+		tv.append(FClient.messages.getString("welcome"), normal);
 	}
 	
 	protected void jButton1ActionPerformed(java.awt.event.ActionEvent e) {
-	
+
 		setVisible(false);
 			
 		FClient.ercheck = true;
