@@ -1,13 +1,14 @@
 /*
- * GNU.FREE 2001
+ * GNU.FREE 2002
  *
- * Copyright (c) 1999, 2000, 2001 The Free Software Foundation (www.fsf.org)
+ * Copyright (c) 1999, 2000, 2001, 2002
+ * The Free Software Foundation (www.fsf.org)
  *
- * GNU.FREE Co-ordinator: Jason Kitcat <jeep@thecouch.org>
+ * GNU.FREE Co-ordinator: Jason Kitcat <jeep@free-project.org>
  *
- * GNU site: http://www.gnu.org/software/gnu.free/gnufree.html
+ * GNU site: http://www.gnu.org/software/free/
  * 
- * FREE e-democracy site: http://www.thecouch.org/free/
+ * FREE e-democracy site: http://www.free-project.org
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +21,7 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program (gpl.txt); if not, write to the Free Software
+ * along with this program (COPYING); if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
@@ -35,7 +36,7 @@ import Free.awt.*;
  /**
   * A screen to let voters enter their information for Electoral Roll authorisation.
  *
- * @version 0.7 20 February 2001
+ * @version 0.8 28 October 2001
  * @author Jason Kitcat, Rajagopal C.V
   */
 public class FCFrame3 extends Frame 
@@ -53,15 +54,16 @@ public class FCFrame3 extends Frame
 
 	protected FCFrame3() {
 		
-		setTitle("FREE: User Authentication");
-		jLabel4.setText("Using your voter card, fill out the fields:");
-		jLabel1.setText("Name:");
-		jLabel2.setText("Code:");
-		jButton1.setLabel("OK");
-		jLabel3.setText("Password:");
+		setTitle(FClient.messages.getString("auth_title"));
+		jLabel4.setText(FClient.messages.getString("auth_instruct"));
+		jLabel1.setText(FClient.messages.getString("name"));
+		jLabel2.setText(FClient.messages.getString("code"));
+		jButton1.setLabel(FClient.messages.getString("ok_button"));
+		jLabel3.setText(FClient.messages.getString("password"));
+		jLabel5.setText(FClient.messages.getString("fill_all"));
 		jPasswordField1.setEchoChar('*');
 			
-		FreePanel scrollPanel = new FreePanel("Voter Card");
+		FreePanel scrollPanel = new FreePanel(FClient.messages.getString("auth"));
 		scrollPanel.setInsets(3, 3, 3, 3);
 		
 		scrollPanel.addComponent( 0, 0, 1, 2, 0, 0, GridBagConstraints.BOTH, 
@@ -113,14 +115,14 @@ public class FCFrame3 extends Frame
 		if (jTextField1.getText().equals("")|jTextField2.getText().equals("")|jPasswordField1.getText().equals("")) {
 			jLabel5.setVisible(true);
 		} else if (!FClient.isSafe(jTextField1.getText())|!FClient.isSafe(jTextField2.getText())|!FClient.isSafe(jPasswordField1.getText())) {
-			jLabel5.setText("Invalid character(s)!");
+			jLabel5.setText(FClient.messages.getString("invalid_chars"));
 			jLabel5.setVisible(true);
 		} else {
 			jLabel5.setText("");
 			jLabel5.setVisible(false);
 			setVisible(false);
 			FClient.frame4.setVisible(true);
-			FClient.frame4.showInfo("Authorising your details...");
+			FClient.frame4.showInfo(FClient.messages.getString("auth_details"));
 			FClient.comms.sendAuth(jTextField1.getText(), jTextField2.getText(), jPasswordField1.getText());
 		}
 	
