@@ -1,13 +1,14 @@
 /*
- * GNU.FREE 2001
+ * GNU.FREE 2002
  *
- * Copyright (c) 1999, 2000, 2001 The Free Software Foundation (www.fsf.org)
+ * Copyright (c) 1999, 2000, 2001, 2002
+ * The Free Software Foundation (www.fsf.org)
  *
- * GNU.FREE Co-ordinator: Jason Kitcat <jeep@thecouch.org>
+ * GNU.FREE Co-ordinator: Jason Kitcat <jeep@free-project.org>
  *
- * GNU site: http://www.gnu.org/software/gnu.free/gnufree.html
+ * GNU site: http://www.gnu.org/software/free/
  * 
- * FREE e-democracy site: http://www.thecouch.org/free/
+ * FREE e-democracy site: http://www.free-project.org
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +21,7 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program (gpl.txt); if not, write to the Free Software
+ * along with this program (COPYING); if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
@@ -35,7 +36,7 @@ import Free.awt.*;
 /**
  * Screen to show progress of voter authentication.
  *
- * @version 0.5 26 February 2001
+ * @version 0.6.5 12 April 2001
  * @author Jason Kitcat, Rajagopal C.V
  */
 public class FCFrame4 extends Frame 
@@ -43,21 +44,39 @@ public class FCFrame4 extends Frame
 
 	protected static boolean status;
 
-	TextArea jTextPane1 = new TextArea();
+    TextView tv;
+	ScrollView sv;
+	Font f;
+	Font f2;
+	TextStyle normal;
+	TextStyle red;
+	TextStyle blue;
+	TextStyle green;
 	Button jButton1 = new Button();
 	Button jButton2 = new Button();
 
 	protected FCFrame4() {
 	
-		jButton1.setLabel("OK");
-		jButton2.setLabel("Quit");
-		setTitle("FREE Authorisation");
+		// prepare textView
+		tv = new TextView(true);
+        sv = new ScrollView(tv);
+        f = new Font("Courier", Font.PLAIN, 12);
+        f2 = new Font("Courier", Font.BOLD, 12);
+        normal = new TextStyle(f, Color.black);
+        red = new TextStyle(f2, Color.red);
+        blue = new TextStyle(f, Color.blue);
+        green = new TextStyle(f, Color.green);
+        
+		// build frame
+		jButton1.setLabel(FClient.messages.getString("ok_button"));
+		jButton2.setLabel(FClient.messages.getString("quit_button"));
+		setTitle(FClient.messages.getString("auth_title"));
 
 		FreePanel scrollPanel = new FreePanel(" ");
 		scrollPanel.setInsets(3, 3, 3, 3);
 		
 		scrollPanel.addComponent( 0, 0, 1, 2, 0, 0, GridBagConstraints.BOTH, 
-			1.0f, 1.0f, jTextPane1);
+			1.0f, 1.0f, sv);
 		scrollPanel.addComponent( 2, 0, 1, 1, 0, 0, GridBagConstraints.BOTH, 
 			1.0f, 0.0f, jButton1);
 		scrollPanel.addComponent( 2, 1, 1, 1, 0, 0, GridBagConstraints.BOTH, 
@@ -98,13 +117,14 @@ public class FCFrame4 extends Frame
   
 	// Show an warning message (red, bold text)
 	protected void showError(String msg) {
-		showMsg(msg);
+		msg += "\n";
+		tv.append(msg, red);
 	}
 	
 	// Show a text message using the specified AttributeSet
 	protected void showMsg(String msg) {
 		msg += "\n";
-		jTextPane1.setText(jTextPane1.getText() + msg);
+		tv.append(msg, normal);
 	}
 	
 
