@@ -1,13 +1,14 @@
 /*
- * GNU.FREE 2001
+ * GNU.FREE 2002
  *
- * Copyright (c) 1999, 2000, 2001 The Free Software Foundation (www.fsf.org)
+ * Copyright (c) 1999, 2000, 2001, 2002
+ * The Free Software Foundation (www.fsf.org)
  *
- * GNU.FREE Co-ordinator: Jason Kitcat <jeep@thecouch.org>
+ * GNU.FREE Co-ordinator: Jason Kitcat <jeep@free-project.org>
  *
- * GNU site: http://www.gnu.org/software/gnu.free/gnufree.html
+ * GNU site: http://www.gnu.org/software/free/
  * 
- * FREE e-democracy site: http://www.thecouch.org/free/
+ * FREE e-democracy site: http://www.free-project.org
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +21,7 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program (gpl.txt); if not, write to the Free Software
+ * along with this program (COPYING); if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
@@ -30,16 +31,33 @@ package FreeClient;
 import java.net.*;
 import java.io.*;
 import java.awt.*;
+import java.util.*;
 
 import Free.awt.*;
+import Free.util.*;
+
 /**
  * FClient Class initialises and starts the FreeClient software.
  *
- * @version 0.6 30 January 2001
+ * @version 0.8 28 October 2001
  * @author Jason Kitcat, Rajagopal C.V
  */
 public class FClient {
 
+	/* Strings to store language details */
+	protected static String language = "en";
+	//protected static String language = "fr";
+	protected static String country = "GB";
+	//protected static String country = "FR";
+
+	/** defines the voting system */
+//#ifdef INSTALL
+	protected static final String vote_system = "borda-default";
+//#ifdef INSTALL
+	protected static final int number_of_choices = 4;
+//#ifdef INSTALL
+	protected static final String write_in = "no";
+
 	/* Time, in milliseconds, before a connection times out */
 	protected static final long timeOutTime = 240000;
 
@@ -49,6 +67,11 @@ public class FClient {
 	/* variable for stopping comms after time out */
 	protected static boolean carryOn = true;
 	
+	/* stores which language to run in */
+	protected static Locale currentLocale;
+	
+	protected static ResourceBundle messages;
+
 	protected static VoteFrame frame;
 	protected static FCFrame2 frame2;
 	protected static FCFrame3 frame3;
@@ -56,7 +79,7 @@ public class FClient {
 	protected static Comms comms;
 
 	/**
-	 * FClient() is the constructor which creates all the Swing frames and
+	 * FClient() is the constructor which creates all the AWT frames and
 	 * launches the splash screen.
 	 *
 	 */
@@ -71,10 +94,17 @@ public class FClient {
 			catch (Exception e) { 
 			}
 			*/
+
+			/* Internationalisation setup */
+			currentLocale = new Locale(language, country);
+		    messages = ResourceBundle.getBundle("FreeClientLang",currentLocale);
 			
+			/* AWT Frames setup */
 			frame2 = new FCFrame2();
 
 			FreePanel.showSplash(4000);
+			RSAEncrypt.init();
+			
 			frame2.initComponents();
 			frame2.setVisible(true);
 			frame = new VoteFrame();
