@@ -1,13 +1,14 @@
 /*
- * GNU.FREE 2001
+ * GNU.FREE 2002
  *
- * Copyright (c) 1999, 2000, 2001 The Free Software Foundation (www.fsf.org)
+ * Copyright (c) 1999, 2000, 2001, 2002
+ * The Free Software Foundation (www.fsf.org)
  *
- * GNU.FREE Co-ordinator: Jason Kitcat <jeep@thecouch.org>
+ * GNU.FREE Co-ordinator: Jason Kitcat <jeep@free-project.org>
  *
- * GNU site: http://www.gnu.org/software/gnu.free/gnufree.html
+ * GNU site: http://www.gnu.org/software/free/
  * 
- * FREE e-democracy site: http://www.thecouch.org/free/
+ * FREE e-democracy site: http://www.free-project.org
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +21,7 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program (gpl.txt); if not, write to the Free Software
+ * along with this program (COPYING); if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
@@ -30,6 +31,8 @@ package FreeClient;
 import java.io.*;
 import java.net.*;
 
+import Free.util.*;
+
 /**
  * TCPClient opens connections to servers and sends/receives all data.
  *
@@ -37,7 +40,7 @@ import java.net.*;
  * with errors, all data is passed to <code>ClientProtocol</code> for
  * for processing.
  *
- * @version 0.8 9 February 2001
+ * @version 1.1 5 July 2001
  * @author Jason Kitcat
  */
 public class TCPClient implements Runnable {
@@ -50,7 +53,7 @@ public class TCPClient implements Runnable {
 	
 		String serverName="";
 		String packetMsg;
-		int port;
+		int port = 0;
 		Socket freeSocket = null;
 		PrintWriter out = null;
 		BufferedReader in = null;
@@ -58,26 +61,28 @@ public class TCPClient implements Runnable {
 		/* get data */
 		if (FClient.comms.getType()=='V') {
 			serverName = FClient.comms.R_address;
+			port = FClient.comms.freeRTPort;
 		} else if (FClient.comms.getType()=='D') {
 			serverName = FClient.comms.R_address;
+			port = FClient.comms.freeRTPort;
 		} else if (FClient.comms.getType()=='E') {
 			serverName = FClient.comms.ER_address;
+			port = FClient.comms.freePort;
 		} else {
-			FClient.frame.showInfo("Unrecognised packet type");
+			FClient.frame.showInfo(FClient.messages.getString("unrec_type"));
 			if (FClient.ercheck) {  // make sure we're sending errors to the right screen
-				FClient.frame4.showError("Couldn't get I/O for the connection to: " + serverName);
+				FClient.frame4.showError(FClient.messages.getString("no_IO") + serverName);
 				FClient.frame4.status=false;
 				FClient.frame4.jButton1.setVisible(true);
 				FClient.frame4.jButton2.setVisible(true);
-				FClient.frame4.showInfo("Click OK to try again.");
+				FClient.frame4.showInfo(FClient.messages.getString("try_again"));
 			} else {
-				FClient.frame.showError("Couldn't get I/O for the connection to: " + serverName);
+				FClient.frame.showError(FClient.messages.getString("no_IO") + serverName);
 				FClient.frame.voteErr();
 			}
 		}
 		
 		packetMsg = FClient.comms.getMessage() + "\r\n";
-		port = FClient.comms.freePort;
 		
 		/* send packet */
 		try {
@@ -89,41 +94,41 @@ public class TCPClient implements Runnable {
 			
 		} catch (UnknownHostException e) {
 			if (FClient.ercheck) {  // make sure we're sending errors to the right screen
-				FClient.frame4.showError("Unknown host: " + serverName);
+				FClient.frame4.showError(FClient.messages.getString("no_host") + serverName);
 				FClient.frame4.status=false;
 				FClient.frame4.jButton1.setEnabled(true);
 				FClient.frame4.jButton2.setEnabled(true);
-				FClient.frame4.showInfo("Click OK to try again.");
+				FClient.frame4.showInfo(FClient.messages.getString("try_again"));
 			} else {
 				FClient.frame.showError("Unknown host: " + serverName);
 				FClient.frame.voteErr();
 			}
 		} catch (IOException e) {
 			if (FClient.ercheck) {  // make sure we're sending errors to the right screen
-				FClient.frame4.showError("Couldn't get I/O for the connection to: " + serverName);
+				FClient.frame4.showError(FClient.messages.getString("no_IO") + serverName);
 				FClient.frame4.status=false;
 				FClient.frame4.jButton1.setEnabled(true);
 				FClient.frame4.jButton2.setEnabled(true);
-				FClient.frame4.showInfo("Click OK to try again.");
+				FClient.frame4.showInfo(FClient.messages.getString("try_again"));
 			} else {
-				FClient.frame.showError("Couldn't get I/O for the connection to: " + serverName);
+				FClient.frame.showError(FClient.messages.getString("no_IO") + serverName);
 				FClient.frame.voteErr();
 			}
 		} catch (Exception e) {
 			if (FClient.ercheck) {  // make sure we're sending errors to the right screen
-				FClient.frame4.showError("Error connecting: " + e.getMessage());
+				FClient.frame4.showError(FClient.messages.getString("err_connect") + e.getMessage());
 				FClient.frame4.status=false;
 				FClient.frame4.jButton1.setEnabled(true);
 				FClient.frame4.jButton2.setEnabled(true);
-				FClient.frame4.showInfo("Click OK to try again.");
+				FClient.frame4.showInfo(FClient.messages.getString("try_again"));
 			} else {
-				FClient.frame.showError("Error connecting: " + e.getMessage());
+				FClient.frame.showError(FClient.messages.getString("err_connect") + e.getMessage());
 				FClient.frame.voteErr();
 			}
 		}
 		
 		String inputData = "NONE";
-		String outputData = "NONE";
+		String[] outputData = new String[] {" ","NONE"};
 		
 		/* read response */
 		try {
@@ -135,22 +140,25 @@ public class TCPClient implements Runnable {
 					inputData = in.readLine();
 					
 					if (!inputData.equals("")) { // check real data has arrived
-		
+						// decrypt data
+						inputData = RSAEncrypt.blowDecrypt(FClient.comms.getsession_key(), inputData);
+
+						// now process
 						outputData = ClientProtocol.process(inputData);
 						
-						if ((outputData.equals("DONE"))|(outputData.equals("ERROR"))) {
+						if ((outputData[1].equals("DONE"))|(outputData[1].equals("ERROR"))) {
 						
 							break;
 							
-						} else if (outputData.charAt(0)=='X') {
+						} else if (outputData[0].charAt(0)=='X') {
 						
-							out.println(outputData);
+							out.println(outputData[1]);
 							
 							break;
 							
 						} else {
 						
-							out.println(outputData);
+							out.println(outputData[1]);
 							
 						}
 						
@@ -163,9 +171,9 @@ public class TCPClient implements Runnable {
 			
 		} catch (Exception e) {
 			if (FClient.ercheck) {  // make sure we're sending errors to the right screen
-				FClient.frame4.showError("Connection Error: " + e.getMessage());
+				FClient.frame4.showError(FClient.messages.getString("connect_err") + e.getMessage());
 			} else {	
-				FClient.frame.showError("Connection Error: " + e.getMessage());
+				FClient.frame.showError(FClient.messages.getString("connect_err") + e.getMessage());
 			}
 		} finally {
 			//tidy up
@@ -175,17 +183,16 @@ public class TCPClient implements Runnable {
 				freeSocket.close();
 			} catch (Exception e) {
 				if (FClient.ercheck) {  // make sure we're sending errors to the right screen
-					FClient.frame4.showError("Error shutting connection: " + e.getMessage());
+					FClient.frame4.showError(FClient.messages.getString("err_shut") + e.getMessage());
 				} else {
-					FClient.frame.showError("Error shutting connection: " + e.getMessage());
+					FClient.frame.showError(FClient.messages.getString("err_shut") + e.getMessage());
 				}
 			}
 			FClient.comms.timer.stopThread();
-			FClient.comms.setFromServer(outputData);
+			FClient.comms.timer = null;
+			FClient.comms.setFromServer(outputData[1]);
 		}
 		
-		FClient.comms.timer.stopThread();
-	
 	} //EOF run
 	
 } //EOF TCPClient
\ No newline at end of file
