@@ -1,13 +1,14 @@
 /*
- * GNU.FREE 2001
+ * GNU.FREE 2002
  *
- * Copyright (c) 1999, 2000, 2001 The Free Software Foundation (www.fsf.org)
+ * Copyright (c) 1999, 2000, 2001, 2002
+ * The Free Software Foundation (www.fsf.org)
  *
- * GNU.FREE Co-ordinator: Jason Kitcat <jeep@thecouch.org>
+ * GNU.FREE Co-ordinator: Jason Kitcat <jeep@free-project.org>
  *
- * GNU site: http://www.gnu.org/software/gnu.free/gnufree.html
+ * GNU site: http://www.gnu.org/software/free/
  * 
- * FREE e-democracy site: http://www.thecouch.org/free/
+ * FREE e-democracy site: http://www.free-project.org
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +21,7 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program (gpl.txt); if not, write to the Free Software
+ * along with this program (COPYING); if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
@@ -35,7 +36,7 @@ import Free.awt.*;
  /**
   * A screen to let users easily set the FREE code variables.
   *
-  * @version 0.2 31 January 2001
+  * @version 0.3 10 April 2001
   * @author Jason Kitcat, Rajagopal C.V
   */
 public class InstallFrame extends Frame 
@@ -46,10 +47,12 @@ public class InstallFrame extends Frame
 	Label jLabel3 = new Label();
 	Label jLabel4 = new Label();
 	Label jLabel6 = new Label();
+	Label jLabel7 = new Label();
 	TextField jTextField1 = new TextField();
 	TextField jTextField2 = new TextField();
 	TextField jTextField3 = new TextField();
 	TextField jTextField4 = new TextField();
+	TextField jTextField5 = new TextField();
 	Button jButton1 = new Button();
 	Label jLabel5 = new Label();
 
@@ -61,7 +64,8 @@ public class InstallFrame extends Frame
 		jLabel1.setText("Regional Server name:");
 		jLabel2.setText("Electoral Roll Server name:");
 		jLabel3.setText("Totaller Server name:");
-		jLabel6.setText("FREE port number (>1024):");
+		jLabel6.setText("ERServer port number (>1024):");
+		jLabel7.setText("RTServer port number (>1024):");
 		jLabel5.setText("Please fill out ALL the fields!");
 		jButton1.setLabel("OK");
 	
@@ -87,16 +91,20 @@ public class InstallFrame extends Frame
 		scrollPanel.addComponent( 8, 0, 1, 2, 0, 0, GridBagConstraints.BOTH, 
 			1.0f, 0.0f, jTextField4);
 		scrollPanel.addComponent( 9, 0, 1, 1, 0, 0, GridBagConstraints.BOTH, 
+			1.0f, 0.0f, jLabel7);
+		scrollPanel.addComponent( 10, 0, 1, 2, 0, 0, GridBagConstraints.BOTH, 
+			1.0f, 0.0f, jTextField5);
+		scrollPanel.addComponent( 11, 0, 1, 1, 0, 0, GridBagConstraints.BOTH, 
 			1.0f, 0.0f, jLabel5);
 
-		scrollPanel.addComponent( 9, 1, 1, 1, 0, 0, GridBagConstraints.NONE, 
+		scrollPanel.addComponent( 11, 1, 1, 1, 0, 0, GridBagConstraints.NONE, 
 			1.0f, 0.0f, jButton1);
 		add(scrollPanel);
 
 		setLocation(new java.awt.Point(40, 40));
-		setTitle("FREE: Setup (1)");
+		setTitle("GNU.FREE: Setup (1)");
 		setResizable(false);
-		setSize(new java.awt.Dimension(300, 380));
+		setSize(new java.awt.Dimension(300, 440));
 	
 	}
 
@@ -124,10 +132,10 @@ public class InstallFrame extends Frame
 	
 	protected void jButton1ActionPerformed(java.awt.event.ActionEvent e) {
 
-		if (jTextField1.getText().equals("")|jTextField2.getText().equals("")|jTextField3.getText().equals("")|jTextField4.getText().equals("")) {
+		if (jTextField1.getText().equals("")|jTextField2.getText().equals("")|jTextField3.getText().equals("")|jTextField4.getText().equals("")|jTextField5.getText().equals("")) {
 			jLabel5.setVisible(true);
 		} else {
-			if (Install.isSafe(jTextField1.getText())|Install.isSafe(jTextField2.getText())|Install.isSafe(jTextField3.getText())|Install.isSafe(jTextField4.getText())) {
+			if (Install.isSafe(jTextField1.getText())|Install.isSafe(jTextField2.getText())|Install.isSafe(jTextField3.getText())|Install.isSafe(jTextField4.getText())|Install.isSafe(jTextField5.getText())) {
 				setVisible(false);
 				jLabel5.setVisible(false);
 			
@@ -135,9 +143,10 @@ public class InstallFrame extends Frame
 				Install.er_name = jTextField2.getText();
 				Install.totaller_name = jTextField3.getText();
 				Install.freePort = jTextField4.getText();
+				Install.freeRTPort = jTextField5.getText();
 
-				setVisible(false);			
-				Install.frame3.setVisible(true);
+				//Install.frame3.setVisible(true); HISTORIC
+				Install.frame4.setVisible(true);
 				dispose();
 			} else {
 				jLabel5.setVisible(true);
