@@ -1,13 +1,14 @@
 /*
- * GNU.FREE 2001
+ * GNU.FREE 2002
  *
- * Copyright (c) 1999, 2000, 2001 The Free Software Foundation (www.fsf.org)
+ * Copyright (c) 1999, 2000, 2001, 2002
+ * The Free Software Foundation (www.fsf.org)
  *
- * GNU.FREE Co-ordinator: Jason Kitcat <jeep@thecouch.org>
+ * GNU.FREE Co-ordinator: Jason Kitcat <jeep@free-project.org>
  *
- * GNU site: http://www.gnu.org/software/gnu.free/gnufree.html
+ * GNU site: http://www.gnu.org/software/free/
  * 
- * FREE e-democracy site: http://www.thecouch.org/free/
+ * FREE e-democracy site: http://www.free-project.org
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +21,7 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program (gpl.txt); if not, write to the Free Software
+ * along with this program (COPYING); if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
@@ -35,7 +36,7 @@ import Free.awt.*;
  /**
   * A screen to let users easily set the FREE code variables.
   *
-  * @version 0.3 31 January 2001
+  * @version 0.35 9 April 2001
   * @author Jason Kitcat, Rajagopal C.V
   */
 public class KeyInstallFrame extends Frame {
@@ -86,7 +87,7 @@ public class KeyInstallFrame extends Frame {
 			1.0f, 0.0f, jButton1);
 			
 		add(scrollPanel);
-		setTitle("FREE: Setup (4)");
+		setTitle("GNU.FREE: Setup (4)");
 		setResizable(true);
 		setSize(new java.awt.Dimension(320, 380));
 		
@@ -126,9 +127,7 @@ public class KeyInstallFrame extends Frame {
 				Install.secret_key2 = jTextField2.getText();
 				Install.MAC_key = jTextField3.getText();
 
-				setVisible(false);			
-				Install.frame.setVisible(true);
-				Install.doInstallation();		
+				Install.frame6.setVisible(true);
 				dispose();
 			} else {
 				jLabel5.setVisible(true);
