@@ -1,13 +1,14 @@
 /*
- * GNU.FREE 2001
+ * GNU.FREE 2002
  *
- * Copyright (c) 1999, 2000, 2001 The Free Software Foundation (www.fsf.org)
+ * Copyright (c) 1999, 2000, 2001, 2002
+ * The Free Software Foundation (www.fsf.org)
  *
- * GNU.FREE Co-ordinator: Jason Kitcat <jeep@thecouch.org>
+ * GNU.FREE Co-ordinator: Jason Kitcat <jeep@free-project.org>
  *
- * GNU site: http://www.gnu.org/software/gnu.free/gnufree.html
+ * GNU site: http://www.gnu.org/software/free/
  * 
- * FREE e-democracy site: http://www.thecouch.org/free/
+ * FREE e-democracy site: http://www.free-project.org
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +21,7 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program (gpl.txt); if not, write to the Free Software
+ * along with this program (COPYING); if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
@@ -63,7 +64,7 @@ public class VoteInstallFrame extends Frame
 		jLabel5.setText("Please fill out ALL the fields!");
 		jButton1.setLabel("OK");
 			
-		FreePanel scrollPanel = new FreePanel("Key Installer");
+		FreePanel scrollPanel = new FreePanel("Vote Choices");
 		scrollPanel.setInsets(3, 3, 3, 3);
 		
 		scrollPanel.addComponent( 0, 0, 1, 2, 0, 0, GridBagConstraints.BOTH, 
@@ -92,7 +93,7 @@ public class VoteInstallFrame extends Frame
 		add(scrollPanel);
 
 		setLocation(new java.awt.Point(40, 40));
-		setTitle("FREE: Setup (2)");
+		setTitle("GNU.FREE: Setup (2)");
 		setResizable(true);
 		setSize(new java.awt.Dimension(300, 380));
 			
@@ -134,7 +135,6 @@ public class VoteInstallFrame extends Frame
 				Install.party3 = jTextField3.getText();
 				Install.party4 = jTextField4.getText();
 
-				setVisible(false);			
 				Install.frame4.setVisible(true);
 				dispose();
 			} else {
