@@ -1,13 +1,14 @@
 /*
- * GNU.FREE 2001
+ * GNU.FREE 2002
  *
- * Copyright (c) 1999, 2000, 2001 The Free Software Foundation (www.fsf.org)
+ * Copyright (c) 1999, 2000, 2001, 2002
+ * The Free Software Foundation (www.fsf.org)
  *
- * GNU.FREE Co-ordinator: Jason Kitcat <jeep@thecouch.org>
+ * GNU.FREE Co-ordinator: Jason Kitcat <jeep@free-project.org>
  *
- * GNU site: http://www.gnu.org/software/gnu.free/gnufree.html
+ * GNU site: http://www.gnu.org/software/free/
  * 
- * FREE e-democracy site: http://www.thecouch.org/free/
+ * FREE e-democracy site: http://www.free-project.org
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +21,7 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program (gpl.txt); if not, write to the Free Software
+ * along with this program (COPYING); if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
@@ -39,7 +40,7 @@ import java.security.*;
  * concatenated with a passphrase is created. This is returned to be added to
  * packets elsewhere.
  *
- * @version 0.4  10 November 2000
+ * @version 0.5  23 June 2001
  * @author Jason Kitcat
  */
 public class AuthSys {
@@ -102,7 +103,7 @@ public class AuthSys {
 	 	
 	 	String origDigest = pack.getDigest();
 	 	
-	 	String mac = makeDigest(pack.getMessage());		
+	 	String mac = makeDigest(pack.getMACMessage());		
 
 	 	if (mac.equals(origDigest)) {
 	 		ok = true;
