@@ -1,13 +1,14 @@
 /*
- * GNU.FREE 2001
+ * GNU.FREE 2002
  *
- * Copyright (c) 1999, 2000, 2001 The Free Software Foundation (www.fsf.org)
+ * Copyright (c) 1999, 2000, 2001, 2002
+ * The Free Software Foundation (www.fsf.org)
  *
- * GNU.FREE Co-ordinator: Jason Kitcat <jeep@thecouch.org>
+ * GNU.FREE Co-ordinator: Jason Kitcat <jeep@free-project.org>
  *
- * GNU site: http://www.gnu.org/software/gnu.free/gnufree.html
+ * GNU site: http://www.gnu.org/software/free/
  * 
- * FREE e-democracy site: http://www.thecouch.org/free/
+ * FREE e-democracy site: http://www.free-project.org
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,14 +21,14 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program (gpl.txt); if not, write to the Free Software
+ * along with this program (COPYING); if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
  
 /**
  * TestProtocol Class
- * @version 0.2  11 November 2000
+ * @version 0.5  23 June 2001
  * @author Jason Kitcat
  */
  
@@ -53,13 +54,13 @@ public class ClientProtocol {
 
 			if (AuthSys.checkDigest(p)) {  // tamper check
 			
-				if (p.getMessage().equals("TRUE")) {
+				if (p.getMessage().charAt(0)=='T') {
 					FTest.frame.showInfo("User authorised to vote!");
 				} else {
 					FTest.frame.showError("User authorisation failed.");
 				}
 				
-				outputData = "X|OK|" + AuthSys.makeDigest("OK") + "\r\n";			
+				outputData = RSAEncrypt.pubEncrypt(FTest.comms.er_public_key,FTest.comms.getsession_key()) + "-" + RSAEncrypt.blowEncrypt(FTest.comms.getsession_key(),"X|OK|" + AuthSys.makeDigest("X|OK")) + "\r\n";			
 
 				if (FTest.comms.isStress) { // profiling for stress tests
 					FTest.comms.doneStress();
@@ -76,11 +77,13 @@ public class ClientProtocol {
 			Packet p = new Packet(inputData);
 
 			if (AuthSys.checkDigest(p)) {  // tamper check
-			
+
 				if (p.getMessage().equals("STAMP")) {
 					if (FTest.comms.getCheck() != null) {
-						String data = FTest.comms.getCheck().toString();
-						outputData = "C|" + data + "|" + AuthSys.makeDigest(data) + "\r\n"; //reply with time stamp
+						String data = FTest.comms.checkStack.elementAt(0).toString();
+						FTest.comms.checkStack.removeElementAt(0);
+						FTest.frame.showInfo(data);
+						outputData = RSAEncrypt.pubEncrypt(FTest.comms.rt_public_key,FTest.comms.getsession_key()) + "-" + RSAEncrypt.blowEncrypt(FTest.comms.getsession_key(),"C|" + data + "|" + AuthSys.makeDigest("C|" + data)) + "\r\n"; //reply with time stamp
 						FTest.frame.showInfo("Time Stamp check sent.");		
 					} else {
 						FTest.frame.showError("Vote security error.");
@@ -88,7 +91,7 @@ public class ClientProtocol {
 					}
 				} else if (p.getMessage().equals("OK")) {  //everything went fine
 					FTest.frame.showInfo("Vote confirmed.");
-					outputData = "X|OK|" + AuthSys.makeDigest("OK") + "\r\n";
+					outputData = RSAEncrypt.pubEncrypt(FTest.comms.rt_public_key,FTest.comms.getsession_key()) + "-" + RSAEncrypt.blowEncrypt(FTest.comms.getsession_key(),"X|OK|" + AuthSys.makeDigest("X|OK")) + "\r\n";
 					
 					if (FTest.comms.isStress) { // profiling for stress tests
 						FTest.comms.doneStress();
@@ -110,7 +113,7 @@ public class ClientProtocol {
 			if (AuthSys.checkDigest(p)) {  // tamper check
 
 				FTest.frame.showInfo("Diagnostic packet received.");
-				outputData = "X|OK|" + AuthSys.makeDigest("OK") + "\r\n";
+				outputData = "X|OK|" + AuthSys.makeDigest("X|OK") + "\r\n";
 			
 			} else {
 				outputData = "ERROR";
@@ -123,7 +126,7 @@ public class ClientProtocol {
 
 			if (AuthSys.checkDigest(p)) {  // tamper check
 				FTest.frame.showInfo("AuthKey packet received: " + p.getMessage());
-				outputData = "X|OK|" + AuthSys.makeDigest("OK") + "\r\n";
+				outputData = RSAEncrypt.pubEncrypt(FTest.comms.er_public_key,FTest.comms.getsession_key()) + "-" + RSAEncrypt.blowEncrypt(FTest.comms.getsession_key(),"X|OK|" + AuthSys.makeDigest("X|OK")) + "\r\n";
 			} else {
 				outputData = "ERROR";
 				throw new Exception("Packet corrupted or altered!");
