@@ -1,13 +1,14 @@
 /*
- * GNU.FREE 2001
+ * GNU.FREE 2002
  *
- * Copyright (c) 1999, 2000, 2001 The Free Software Foundation (www.fsf.org)
+ * Copyright (c) 1999, 2000, 2001, 2002
+ * The Free Software Foundation (www.fsf.org)
  *
- * GNU.FREE Co-ordinator: Jason Kitcat <jeep@thecouch.org>
+ * GNU.FREE Co-ordinator: Jason Kitcat <jeep@free-project.org>
  *
- * GNU site: http://www.gnu.org/software/gnu.free/gnufree.html
+ * GNU site: http://www.gnu.org/software/free/
  * 
- * FREE e-democracy site: http://www.thecouch.org/free/
+ * FREE e-democracy site: http://www.free-project.org
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,14 +21,14 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program (gpl.txt); if not, write to the Free Software
+ * along with this program (COPYING); if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
  
 /**
  * Comms Class
- * @version 0.4 11 November 2000
+ * @version 0.7 23 July 2001
  * @author Jason Kitcat
  */
  
@@ -48,6 +49,16 @@ public class Comms {
 	// constant to store value being used as FREE port number
 	// For security reasons I recommend this is changed regularly
 	protected static final int freePort = 1111;
+	/** public and private keys for communications */
+//#ifdef INSTALL
+	protected static final String rt_public_key = "001101000108008193745AA3A2733EF1140758495439CB4CD188C4F2B5D2FA84C3C533465991257EAFC2BCAC0AC07F1531C97489723A353E7A1C911E687A5E834CD872B534480D8B4F9107E48C994A0D5B68870DE4DC3A51C604572446F166E02B8F234C44158FD373A06CFF30E3BBA2F1E670743D7B855CC2D3EF395D440A702D57013A5146171E4B7C78343FB2DAA47E56C63A2B5CFA57FF8892399F0A7D8E47A0203C687A158D3E0802AE02D3C1EA4AC625B641430FA9A1A50FC095461EED1DF401F93365CD650D02CFD4392BE1349B29900A0DCA648658FAFA3E8C3300E44C705AF3930F5EDF28B5D40C89251F440C9038DD9F533A849965EB71617D91A5CFD5621ED6A5D1";
+//#ifdef INSTALL
+	protected static final String er_public_key = "001101000108009539E6A8D4A7F01D33BBF0E9E273373874AC8A3D226FC75E7F8C464B673E0DF6BEA371B169EC1EDA382A4D5BBD1973963C0B57BE8B0EE16ADF3194D2EAE630B15E2E1BEF2AC34AA8061341D3F6D6010F72210A671F8653A3FC0B03F6F31FB0E480444AE98658D95404EE62C2A5C063F830A4DB52EEB2E02EE6E9310C2A95875CE1D8A1DE8BA03271198A15076F1D65574C1A8C1FF39FAEE8A43EDE11DE22E41ED8E3B1DBC57E58C978259B7A846998E5CFCEDF1EB75F12A6481FD86AA29E2F9184F0BF522F0553EF806927D167187F4F3A7233EB6F3080A7E131C0911EF82C08A86FE4C0F0B6F53E580F81568C59BFE4C131B78F1E66B879858D6C05060058B1";
+//#ifdef INSTALL
+	protected static final String fc_private_key = "";
+	
+	/** Holds the session key for GNU.FREE security protocol */
+	private String session_key;
 	
 	private String fromServer;
 	private Date check;
@@ -59,10 +70,12 @@ public class Comms {
 	protected boolean isStress;
 	protected int stressClients;
 	protected int stressCount;
-	
+	protected Vector checkStack;
+
 	/* constructor */
 	protected Comms() {
 	
+		checkStack = new Vector(1000);
 		// unneccessary but just in case!
 		message = "";
 		fromServer = "";
@@ -87,6 +100,20 @@ public class Comms {
 	
 	}
 	
+	/* simple acessor method */
+	protected String getsession_key() {
+	
+		return session_key;
+	
+	}
+	
+	/* simple acessor method */
+	protected void setsession_key(String x) {
+	
+		session_key = x;
+	
+	}
+	
 	/* simple acessor method */
 	protected Date getCheck() {
 	
@@ -150,7 +177,7 @@ public class Comms {
 	 */
 	 protected void sendVote(String party) {	 
 		
-		Runnable tk = new TCPClient();
+		Runnable tk = new TCPClient(0);
 		talker = new Thread(tk);
 
 		String reply;
@@ -161,7 +188,7 @@ public class Comms {
 
 		try {
 			
-			message = "V|" + data + "|" + AuthSys.makeDigest(data);
+			message = "V|" + data + "|" + AuthSys.makeDigest("V|" + data);
 
 			type = 'V';
 		
@@ -183,14 +210,16 @@ public class Comms {
 	 */
 	 protected void sendVote2(String data) {	 
 		
-		Runnable tk = new TCPClient();
+		Runnable tk = new TCPClient(0);
 		talker = new Thread(tk);
 
 		String reply;
 
 		try {
 			
-			message = "V|" + data + "|" + AuthSys.makeDigest(data);
+			setsession_key(RSAEncrypt.makeSessionKey());
+			
+			message = RSAEncrypt.pubEncrypt(rt_public_key,getsession_key()) + "-" + RSAEncrypt.blowEncrypt(getsession_key(),"V|" + data + "|" + AuthSys.makeDigest("V|" + data));
 
 			type = 'V';
 		
@@ -214,7 +243,7 @@ public class Comms {
 	 */
 	 protected void sendVote3(String party, String MAC) {	 
 		
-		Runnable tk = new TCPClient();
+		Runnable tk = new TCPClient(0);
 		talker = new Thread(tk);
 
 		String reply;
@@ -225,7 +254,9 @@ public class Comms {
 
 		try {
 			
-			message = "V|" + data + "|" + MAC;
+			setsession_key(RSAEncrypt.makeSessionKey());
+			
+			message = RSAEncrypt.pubEncrypt(rt_public_key,getsession_key()) + "-" + RSAEncrypt.blowEncrypt(getsession_key(),"V|" + data + "|" + MAC);
 
 			type = 'V';
 		
@@ -252,7 +283,7 @@ public class Comms {
 	 */
 	protected void sendAuth(String data) {
 	
-		Runnable tk = new TCPClient();
+		Runnable tk = new TCPClient(0);
 		Thread talker = new Thread(tk);
 
 		String reply;
@@ -261,7 +292,9 @@ public class Comms {
 		message = "E|";
 			
 		try {
-			message = message + data + "|" + AuthSys.makeDigest(data);
+			setsession_key(RSAEncrypt.makeSessionKey());
+			
+			message = RSAEncrypt.pubEncrypt(er_public_key,getsession_key()) + "-" + RSAEncrypt.blowEncrypt(getsession_key(),message + data + "|" + AuthSys.makeDigest(message + data));
 		
 		 	talker.start();
 		 	
@@ -283,7 +316,7 @@ public class Comms {
 	 */
 	protected void sendAuth2(String data, String MAC) {
 	
-		Runnable tk = new TCPClient();
+		Runnable tk = new TCPClient(0);
 		Thread talker = new Thread(tk);
 
 		String reply;
@@ -292,7 +325,9 @@ public class Comms {
 		message = "E|";
 			
 		try {
-			message = message + data + "|" + MAC;
+			setsession_key(RSAEncrypt.makeSessionKey());
+			
+			message = RSAEncrypt.pubEncrypt(er_public_key,getsession_key()) + "-" + RSAEncrypt.blowEncrypt(getsession_key(),message + data + "|" + MAC);
 		
 		 	talker.start();
 		 	
@@ -312,7 +347,7 @@ public class Comms {
 	 */
 	 protected void sendKey(String akey) throws Exception {
 		
-		Runnable tk = new TCPClient();
+		Runnable tk = new TCPClient(0);
 		Thread talker = new Thread(tk);
 
 		String reply;
@@ -320,7 +355,9 @@ public class Comms {
 		type = 'K';
 
 		try {
-			message = "K|" + akey + "|" + AuthSys.makeDigest(akey);
+			setsession_key(RSAEncrypt.makeSessionKey());
+			
+			message = RSAEncrypt.pubEncrypt(er_public_key,getsession_key()) + "-" + RSAEncrypt.blowEncrypt(getsession_key(),"K|" + akey + "|" + AuthSys.makeDigest("K|" + akey));
 			
 			FTest.frame.showInfo("Sending AuthKey: " + message);
 			
@@ -342,7 +379,7 @@ public class Comms {
 	 */
 	 protected void sendDiag(String msg) {	 
 		
-		Runnable tk = new TCPClient();
+		Runnable tk = new TCPClient(0);
 		Thread talker = new Thread(tk);
 
 		String reply;
@@ -352,7 +389,7 @@ public class Comms {
 		data = "D|" + msg;
 	
 		try {
-			message = data + "|" + AuthSys.makeDigest(msg);
+			message = data + "|" + AuthSys.makeDigest(data);
 		
 		 	talker.start();
 		 	
