@@ -1,13 +1,14 @@
 /*
- * GNU.FREE 2001
+ * GNU.FREE 2002
  *
- * Copyright (c) 1999, 2000, 2001 The Free Software Foundation (www.fsf.org)
+ * Copyright (c) 1999, 2000, 2001, 2002
+ * The Free Software Foundation (www.fsf.org)
  *
- * GNU.FREE Co-ordinator: Jason Kitcat <jeep@thecouch.org>
+ * GNU.FREE Co-ordinator: Jason Kitcat <jeep@free-project.org>
  *
- * GNU site: http://www.gnu.org/software/gnu.free/gnufree.html
+ * GNU site: http://www.gnu.org/software/free/
  * 
- * FREE e-democracy site: http://www.thecouch.org/free/
+ * FREE e-democracy site: http://www.free-project.org
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,14 +21,14 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program (gpl.txt); if not, write to the Free Software
+ * along with this program (COPYING); if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
  
 /**
  * Stress Class
- * @version 0.1 18 February 2000
+ * @version 0.2 29 March 2001
  * @author Jason Kitcat
  */
  
@@ -36,10 +37,18 @@ package FreeTest;
 
 public class Stress extends Thread {
 
-	Runnable tk = new TCPClient();
-	Thread talker = new Thread(tk);
+	Runnable tk;
+	Thread talker;
 	
+	public int vectIndex = 0;
 	String reply;
+	
+	/* constructor */
+	public Stress(int i) {
+		vectIndex = i;
+		tk = new TCPClient(vectIndex);
+		talker = new Thread(tk);
+	}
 
 	/** This run method spins off a TCPClient thread to send a packet */
 	public void run() {
