@@ -1,13 +1,14 @@
 /*
- * GNU.FREE 2001
+ * GNU.FREE 2002
  *
- * Copyright (c) 1999, 2000, 2001 The Free Software Foundation (www.fsf.org)
+ * Copyright (c) 1999, 2000, 2001, 2002
+ * The Free Software Foundation (www.fsf.org)
  *
- * GNU.FREE Co-ordinator: Jason Kitcat <jeep@thecouch.org>
+ * GNU.FREE Co-ordinator: Jason Kitcat <jeep@free-project.org>
  *
- * GNU site: http://www.gnu.org/software/gnu.free/gnufree.html
+ * GNU site: http://www.gnu.org/software/free/
  * 
- * FREE e-democracy site: http://www.thecouch.org/free/
+ * FREE e-democracy site: http://www.free-project.org
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,14 +21,14 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program (gpl.txt); if not, write to the Free Software
+ * along with this program (COPYING); if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
  
 /**
  * TCPClient Class
- * @version 0.5 11 November 2000
+ * @version 0.7 23 June 2001
  * @author Jason Kitcat
  */
  
@@ -38,6 +39,17 @@ import java.net.*;
 
 public class TCPClient implements Runnable {
 
+	String packetMsg;
+	
+	/* constructor */
+	public TCPClient(int i) {
+		if (FTest.comms.isStress) {
+			packetMsg = FTest.frame.stressVector.elementAt(i) + "\r\n";
+		} else {
+			packetMsg = FTest.comms.getMessage() + "\r\n";
+		}
+	}
+
 	/**
 	 * run() delivers a packet to the server whose DNS address is chosen
 	 * 
@@ -45,7 +57,6 @@ public class TCPClient implements Runnable {
 	public void run() {
 	
 		String serverName;
-		String packetMsg;
 		int port;
 		Socket freeSocket = null;
 		PrintWriter out = null;
@@ -65,7 +76,6 @@ public class TCPClient implements Runnable {
 			serverName = FTest.comms.ER_address;
 		}
 		
-		packetMsg = FTest.comms.getMessage() + "\r\n";
 		port = FTest.comms.freePort;
 		
 		/* send packet */
@@ -73,7 +83,7 @@ public class TCPClient implements Runnable {
 			freeSocket = new Socket(serverName, port);
 			out = new PrintWriter(freeSocket.getOutputStream(), true);
 			in = new BufferedReader(new InputStreamReader(freeSocket.getInputStream()));
-			
+			FTest.frame.showInfo("Sending: " + packetMsg);
 			out.println(packetMsg); //write packet
 		} catch (UnknownHostException e) {
 			FTest.frame.showError("Unknown host: " + serverName);
@@ -94,7 +104,9 @@ public class TCPClient implements Runnable {
 					inputData = in.readLine();
 					
 					if (!inputData.equals("")) { // check real data has arrived
-		
+						// decrypt data
+						inputData = RSAEncrypt.blowDecrypt(FTest.comms.getsession_key(), inputData);
+						// now process
 						outputData = ClientProtocol.process(inputData);
 						
 						if ((outputData.equals("DONE"))|(outputData.equals("ERROR"))) {
